@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glib/gi18n.h>
@@ -6,7 +5,7 @@
 #include <glibtop/close.h>
 #include <glibtop/cpu.h>
 #include <glibtop/sysinfo.h>
-#include <handy.h>
+#include <adwaita.h>
 #include <signal.h>
 #include <stdlib.h>
 
@@ -73,6 +72,7 @@ cb_draw_smooth_changed (Gio::Settings& settings,
   app->cpu_graph->clear_background ();
   app->mem_graph->clear_background ();
   app->net_graph->clear_background ();
+  app->disk_graph->clear_background ();
 }
 
 static void
@@ -92,22 +92,6 @@ cb_network_in_bits_changed (Gio::Settings& settings,
                             GsmApplication*app)
 {
   app->config.network_in_bits = settings.get_boolean (key);
-  if (app->config.network_total_unit == FALSE)
-    app->config.network_total_in_bits = app->config.network_in_bits;
-  // force scale to be redrawn
-  app->net_graph->clear_background ();
-}
-
-static void
-cb_network_total_in_unit_changed (Gio::Settings& settings,
-                                  Glib::ustring  key,
-                                  GsmApplication*app)
-{
-  app->config.network_total_unit = settings.get_boolean (key);
-  if (app->config.network_total_unit == FALSE)
-    app->config.network_total_in_bits = app->config.network_in_bits;
-  else
-    app->config.network_total_in_bits = app->settings->get_boolean (GSM_SETTING_NETWORK_TOTAL_IN_BITS);
   // force scale to be redrawn
   app->net_graph->clear_background ();
 }
@@ -144,6 +128,8 @@ cb_timeouts_changed (Gio::Settings& settings,
                                app->config.graph_update_interval);
       load_graph_change_speed (app->net_graph,
                                app->config.graph_update_interval);
+      load_graph_change_speed (app->disk_graph,
+                               app->config.graph_update_interval);
     }
   else if (key == GSM_SETTING_DISKS_UPDATE_INTERVAL)
     {
@@ -163,6 +149,7 @@ cb_data_points_changed (Gio::Settings& settings,
   load_graph_change_num_points (app->cpu_graph, points);
   load_graph_change_num_points (app->mem_graph, points);
   load_graph_change_num_points (app->net_graph, points);
+  load_graph_change_num_points (app->disk_graph, points);
 }
 
 static void
@@ -249,6 +236,16 @@ cb_color_changed (Gio::Settings& settings,
       gdk_rgba_parse (&app->config.net_out_color, color.c_str ());
       app->net_graph->colors.at (1) = app->config.net_out_color;
     }
+  else if (key == GSM_SETTING_DISK_READ_COLOR)
+    {
+      gdk_rgba_parse (&app->config.disk_read_color, color.c_str ());
+      app->disk_graph->colors.at (0) = app->config.disk_read_color;
+    }
+  else if (key == GSM_SETTING_DISK_WRITE_COLOR)
+    {
+      gdk_rgba_parse (&app->config.disk_write_color, color.c_str ());
+      app->disk_graph->colors.at (1) = app->config.disk_write_color;
+    }
 }
 
 void
@@ -295,20 +292,7 @@ GsmApplication::load_settings ()
     cb_network_in_bits_changed (*this->settings.operator-> (), key, this);
   });
 
-  config.network_total_unit = this->settings->get_boolean (GSM_SETTING_NETWORK_TOTAL_UNIT);
-  this->settings->signal_changed (GSM_SETTING_NETWORK_TOTAL_UNIT).connect ([this](const Glib::ustring&key) {
-    cb_network_total_in_unit_changed (*this->settings.operator-> (), key, this);
-  });
-
-  if (config.network_total_unit == FALSE)
-    {
-      config.network_total_in_bits = config.network_in_bits;
-      this->settings->set_boolean (GSM_SETTING_NETWORK_TOTAL_IN_BITS, config.network_in_bits);
-    }
-  else
-    {
-      config.network_total_in_bits = this->settings->get_boolean (GSM_SETTING_NETWORK_TOTAL_IN_BITS);
-    }
+  config.network_total_in_bits = this->settings->get_boolean (GSM_SETTING_NETWORK_TOTAL_IN_BITS);
   this->settings->signal_changed (GSM_SETTING_NETWORK_TOTAL_IN_BITS).connect ([this](const Glib::ustring&key) {
     cb_network_total_in_bits_changed (*this->settings.operator-> (), key, this);
   });
@@ -352,46 +336,62 @@ GsmApplication::load_settings ()
 
   gdk_rgba_parse (&config.net_out_color, net_out_color.empty () ? "#00f2000000c1" : net_out_color.c_str ());
 
+  auto disk_read_color = this->settings->get_string (GSM_SETTING_DISK_READ_COLOR);
+
+  gdk_rgba_parse (&config.disk_read_color, disk_read_color.empty () ? "#000000f200f2" : disk_read_color.c_str ());
+
+  auto disk_write_color = this->settings->get_string (GSM_SETTING_DISK_WRITE_COLOR);
+
+  gdk_rgba_parse (&config.disk_write_color, disk_write_color.empty () ? "#00f2000000c1" : disk_write_color.c_str ());
+
+
   auto cbcc = [this](const Glib::ustring&key) {
                 cb_color_changed (*this->settings.operator-> (), key, this);
               };
 
-  for (auto k : { GSM_SETTING_CPU_COLORS, GSM_SETTING_MEM_COLOR, GSM_SETTING_SWAP_COLOR, GSM_SETTING_NET_IN_COLOR, GSM_SETTING_NET_OUT_COLOR })
+  for (auto k : { GSM_SETTING_CPU_COLORS, GSM_SETTING_MEM_COLOR, GSM_SETTING_SWAP_COLOR, GSM_SETTING_NET_IN_COLOR, GSM_SETTING_NET_OUT_COLOR, GSM_SETTING_DISK_READ_COLOR, GSM_SETTING_DISK_WRITE_COLOR })
     this->settings->signal_changed (k).connect (cbcc);
 }
 
 
 GsmApplication::GsmApplication()
-  : Gtk::Application ("org.gnome.SystemMonitor", Gio::APPLICATION_HANDLES_COMMAND_LINE),
+  : Gtk::Application (APP_ID, Gio::Application::Flags::HANDLES_COMMAND_LINE),
+  settings (NULL),
+  main_window (NULL),
+  stack (NULL),
+  app_menu_button (NULL),
+
+  config (),
+  pretty_table (NULL),
   tree (NULL),
   proc_actionbar_revealer (NULL),
-  popup_menu (NULL),
-  disk_list (NULL),
-  stack (NULL),
+  proc_popover_menu (NULL),
   refresh_button (NULL),
-  process_menu_button (NULL),
-  window_menu_button (NULL),
   end_process_button (NULL),
   search_button (NULL),
   search_entry (NULL),
   search_bar (NULL),
-  config (),
+  top_of_tree (NULL),
+
+  last_vscroll_max (0.0),
+  last_vscroll_value (0.0),
+  timeout (0U),
+  cpu_total_time (0ULL),
+  cpu_total_time_last (0ULL),
+  frequency (0U),
+
   cpu_graph (NULL),
   mem_graph (NULL),
   net_graph (NULL),
-  selection (NULL),
-  timeout (0U),
+  disk_graph (NULL),
+
+  disk_list (NULL),
+
   disk_timeout (0U),
-  top_of_tree (NULL),
-  last_vscroll_max (0.0),
-  last_vscroll_value (0.0),
-  pretty_table (NULL),
-  settings (NULL),
-  main_window (NULL),
-  frequency (0U),
-  smooth_refresh (NULL),
-  cpu_total_time (0ULL),
-  cpu_total_time_last (0ULL)
+
+  selection (NULL),
+
+  smooth_refresh (NULL)
 {
   Glib::set_application_name (_("System Monitor"));
 }
@@ -412,44 +412,25 @@ GsmApplication::on_activate ()
   gtk_window_present (GTK_WINDOW (main_window));
 }
 
-void
-GsmApplication::save_config ()
-{
-  int width, height, xpos, ypos;
-  gboolean maximized;
-
-  gtk_window_get_size (GTK_WINDOW (main_window), &width, &height);
-  gtk_window_get_position (GTK_WINDOW (main_window), &xpos, &ypos);
-
-  maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (main_window))) & GDK_WINDOW_STATE_MAXIMIZED;
-
-  g_settings_set (settings->gobj (), GSM_SETTING_WINDOW_STATE, "(iiii)",
-                  width, height, xpos, ypos);
-
-  settings->set_boolean (GSM_SETTING_MAXIMIZED, maximized);
-}
-
 int
 GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>&command_line)
 {
   int argc = 0;
-  char**argv = command_line->get_arguments (argc);
+  char **argv = command_line->get_arguments (argc);
 
   Glib::OptionContext context;
 
   context.set_summary (_("A simple process and system monitor."));
   context.set_ignore_unknown_options (true);
 
-  Glib::OptionGroup gtkgroup (gtk_get_option_group (true));
   procman::OptionGroup option_group;
 
   context.set_main_group (option_group);
-  context.add_group (gtkgroup);
 
   try {
       context.parse (argc, argv);
     } catch (const Glib::Error&ex) {
-      g_error ("Arguments parse error : %s", ex.what ().c_str ());
+      g_error ("Arguments parse error : %s", ex.what ());
     }
 
   g_strfreev (argv);
@@ -460,7 +441,7 @@ GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>
       exit (EXIT_SUCCESS);
     }
 
-  const char* tab = NULL;
+  const char*tab = NULL;
   if (option_group.show_processes_tab)
     tab = "processes";
   else if (option_group.show_resources_tab)
@@ -468,7 +449,7 @@ GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>
   else if (option_group.show_file_systems_tab)
     tab = "disks";
   if (tab)
-    gtk_stack_set_visible_child_name (this->stack, tab);
+    adw_view_stack_set_visible_child_name (this->stack, tab);
 
   on_activate ();
 
@@ -508,8 +489,6 @@ GsmApplication::on_quit_activate (const Glib::VariantBase&)
 void
 GsmApplication::shutdown ()
 {
-  save_config ();
-
   if (timeout)
     g_source_remove (timeout);
   if (disk_timeout)
@@ -527,16 +506,19 @@ GsmApplication::shutdown ()
 void
 GsmApplication::on_startup ()
 {
-  HdyStyleManager *style_manager;
+  AdwStyleManager *style_manager;
 
   Gtk::Application::on_startup ();
 
-  hdy_init ();
+  glibtop_init ();
 
   load_resources ();
+  load_settings ();
 
-  style_manager = hdy_style_manager_get_default ();
-  hdy_style_manager_set_color_scheme (style_manager, HDY_COLOR_SCHEME_PREFER_LIGHT);
+  style_manager = adw_style_manager_get_default ();
+  adw_style_manager_set_color_scheme (style_manager, ADW_COLOR_SCHEME_PREFER_LIGHT);
+
+  Gtk::Window::set_default_icon_name (APP_ID);
 
   Glib::RefPtr<Gio::SimpleAction> action;
 
@@ -558,28 +540,24 @@ GsmApplication::on_startup ()
 
   Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_resource ("/org/gnome/gnome-system-monitor/data/menus.ui");
 
-  Glib::RefPtr<Gio::Menu> menu = Glib::RefPtr<Gio::Menu>::cast_static (builder->get_object ("app-menu"));
-
-  set_app_menu (menu);
-
-  add_accelerator ("<Primary>d", "win.show-dependencies", NULL);
-  add_accelerator ("<Primary>q", "app.quit", NULL);
-  add_accelerator ("<Primary>s", "win.send-signal-stop", g_variant_new_int32 (SIGSTOP));
-  add_accelerator ("<Primary>c", "win.send-signal-cont", g_variant_new_int32 (SIGCONT));
-  add_accelerator ("<Primary>t", "win.send-signal-term", g_variant_new_int32 (SIGTERM));
-  add_accelerator ("<Primary>k", "win.send-signal-kill", g_variant_new_int32 (SIGKILL));
-  add_accelerator ("<Alt>s", "win.set-affinity", NULL);
-  add_accelerator ("<Primary>m", "win.memory-maps", NULL);
-  add_accelerator ("<Primary>o", "win.open-files", NULL);
-  add_accelerator ("<Alt>Return", "win.process-properties", NULL);
-  add_accelerator ("<Primary>f", "win.search", g_variant_new_boolean (TRUE));
-  add_accelerator ("F1", "app.help", NULL);
-  add_accelerator ("<Primary>question", "win.show-help-overlay", NULL);
-  add_accelerator ("<Primary>comma", "app.preferences", NULL);
-
-  Gtk::Window::set_default_icon_name ("org.gnome.SystemMonitor");
-
-  glibtop_init ();
+  set_accel_for_action ("win.show-dependencies", "<Primary>d");
+  set_accel_for_action ("app.quit", "<Primary>q");
+  set_accel_for_action ("win.send-signal-stop", "<Primary>s");
+  set_accel_for_action ("win.send-signal-cont", "<Primary>c");
+  set_accel_for_action ("win.send-signal-term", "<Primary>t");
+  set_accel_for_action ("win.send-signal-kill", "<Primary>k");
+  set_accel_for_action ("win.set-affinity", "<Alt>s");
+  set_accel_for_action ("win.memory-maps", "<Control>m");
+  set_accel_for_action ("win.open-files", "<Control>o");
+  set_accel_for_action ("win.process-properties", "<Alt>Return");
+  set_accel_for_action ("win.search", "<Control>f");
+  set_accel_for_action ("app.help", "F1");
+  set_accel_for_action ("win.show-help-overlay", "<Control>question");
+  set_accel_for_action ("app.preferences", "<Primary>comma");
+  set_accel_for_action ("win.show-page('processes')", "<Alt>1");
+  set_accel_for_action ("win.show-page('resources')", "<Alt>2");
+  set_accel_for_action ("win.show-page('disks')", "<Alt>3");
+  set_accel_for_action ("win.refresh", "<Control>r");
 
   load_settings ();
 
@@ -587,16 +565,8 @@ GsmApplication::on_startup ()
   smooth_refresh = new SmoothRefresh (settings);
 
   create_main_window (this);
-
-  add_accelerator ("<Alt>1", "win.show-page", g_variant_new_string ("processes"));
-  add_accelerator ("<Alt>2", "win.show-page", g_variant_new_string ("resources"));
-  add_accelerator ("<Alt>3", "win.show-page", g_variant_new_string ("disks"));
-  add_accelerator ("<Primary>r", "win.refresh", NULL);
-
-  gtk_widget_show (GTK_WIDGET (main_window));
 }
 
-
 void
 GsmApplication::load_resources ()
 {
