@@ -1,12 +1,12 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #ifndef _GSM_APPLICATION_H_
 #define _GSM_APPLICATION_H_
 
 #include <gtkmm.h>
 #include <glibtop/cpu.h>
-#include <handy.h>
+#include <adwaita.h>
 
 #include <algorithm>
+#include <mutex>
 
 struct LoadGraph;
 
@@ -30,7 +30,7 @@ enum ProcmanTab
 struct ProcConfig
   : private procman::NonCopyable
 {
-  ProcConfig()
+  ProcConfig ()
     : current_tab (),
     update_interval (0),
     graph_update_interval (0),
@@ -40,6 +40,8 @@ struct ProcConfig
     swap_color (),
     net_in_color (),
     net_out_color (),
+    disk_read_color (),
+    disk_write_color (),
     bg_color (),
     frame_color (),
     num_cpus (0),
@@ -50,7 +52,6 @@ struct ProcConfig
     draw_smooth (true),
     resources_memory_in_iec (true),
     network_in_bits (false),
-    network_total_unit (false),
     network_total_in_bits (false)
   {
     std::fill (&this->cpu_color[0], &this->cpu_color[GLIBTOP_NCPU], GdkRGBA ());
@@ -66,6 +67,8 @@ struct ProcConfig
   GdkRGBA swap_color;
   GdkRGBA net_in_color;
   GdkRGBA net_out_color;
+  GdkRGBA disk_read_color;
+  GdkRGBA disk_write_color;
   GdkRGBA bg_color;
   GdkRGBA frame_color;
   gint num_cpus;
@@ -76,7 +79,6 @@ struct ProcConfig
   bool draw_smooth;
   bool resources_memory_in_iec;
   bool network_in_bits;
-  bool network_total_unit;
   bool network_total_in_bits;
 };
 
@@ -85,15 +87,12 @@ struct ProcConfig
 struct MutableProcInfo
   : private procman::NonCopyable
 {
-  MutableProcInfo()
+  MutableProcInfo ()
     : vmsize (0UL),
     memres (0UL),
     memshared (0UL),
     memwritable (0UL),
     mem (0UL),
-#ifdef HAVE_WNCK
-    memxserver (0UL),
-#endif
     start_time (0UL),
     cpu_time (0ULL),
     disk_read_bytes_total (0ULL),
@@ -120,11 +119,6 @@ struct MutableProcInfo
   gulong memwritable;
   gulong mem;
 
-#ifdef HAVE_WNCK
-  // wnck gives an unsigned long
-  gulong memxserver;
-#endif
-
   gulong start_time;
   guint64 cpu_time;
   guint64 disk_read_bytes_total;
@@ -151,13 +145,14 @@ public:
 ProcInfo& operator= (const ProcInfo&) = delete;
 ProcInfo(const ProcInfo&) = delete;
 ProcInfo(pid_t pid);
+
 // adds one more ref to icon
-void              set_icon (Glib::RefPtr<Gdk::Pixbuf> icon);
-void              set_user (guint uid);
-std::string       lookup_user (guint uid);
+void        set_icon (Glib::RefPtr<Gdk::Texture> icon);
+void        set_user (guint uid);
+std::string lookup_user (guint uid);
 
 GtkTreeIter node;
-Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+Glib::RefPtr<Gdk::Texture> icon;
 std::string tooltip;
 std::string name;
 std::string arguments;
@@ -225,55 +220,56 @@ void                                on_help_activate (const Glib::VariantBase&);
 void                                on_quit_activate (const Glib::VariantBase&);
 protected:
 GsmApplication();
+
+virtual void                        on_activate ();
+virtual int                         on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>&command_line);
+virtual void                        on_startup ();
 public:
 static Glib::RefPtr<GsmApplication> get ();
 
 void                                save_config ();
 void                                shutdown ();
 
+Glib::RefPtr<Gio::Settings> settings;
+AdwApplicationWindow *main_window;
+AdwViewStack     *stack;
+GtkMenuButton    *app_menu_button;
+
+GMenuModel *generic_window_menu_model;
+GMenuModel *process_window_menu_model;
+
 ProcList processes;
+ProcConfig config;
+PrettyTable      *pretty_table;
 GsmTreeView      *tree;
 GtkRevealer      *proc_actionbar_revealer;
-GtkMenu          *popup_menu;
-GsmTreeView      *disk_list;
-GtkStack         *stack;
+GtkPopover       *proc_popover_menu;
 GtkButton        *refresh_button;
-GtkMenuButton    *process_menu_button;
-GtkMenuButton    *window_menu_button;
 GtkButton        *end_process_button;
-GtkButton        *search_button;
+GtkToggleButton  *search_button;
 GtkSearchEntry   *search_entry;
 GtkSearchBar     *search_bar;
-ProcConfig config;
+GtkTreePath      *top_of_tree;
+
+gdouble last_vscroll_max;
+gdouble last_vscroll_value;
+guint timeout;
+guint64 cpu_total_time;
+guint64 cpu_total_time_last;
+unsigned frequency;
+
 LoadGraph        *cpu_graph;
 LoadGraph        *mem_graph;
 LoadGraph        *net_graph;
-gint cpu_label_fixed_width;
-gint net_label_fixed_width;
-GtkTreeSelection *selection;
-guint timeout;
+LoadGraph        *disk_graph;
+
+GsmTreeView      *disk_list;
+
 guint disk_timeout;
 
-GtkTreePath      *top_of_tree;
-gdouble last_vscroll_max;
-gdouble last_vscroll_value;
-
-PrettyTable      *pretty_table;
-
-Glib::RefPtr<Gio::Settings> settings;
-HdyApplicationWindow *main_window;
-
-unsigned frequency;
+GtkTreeSelection *selection;
 
 SmoothRefresh    *smooth_refresh;
-
-guint64 cpu_total_time;
-guint64 cpu_total_time_last;
-
-protected:
-virtual void on_activate ();
-virtual int  on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>&command_line);
-virtual void on_startup ();
 };
 
 #endif /* _GSM_APPLICATION_H_ */
