@@ -1,5 +1,6 @@
 #include <config.h>
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
@@ -23,7 +24,7 @@ enum DiskColumns
   /* USED has to be the last column */
   DISK_USED,
   // then invisible columns
-  /* PixBuf column */
+  /* icon column */
   DISK_ICON,
   /* numeric columns */
   DISK_USED_PERCENTAGE,
@@ -31,8 +32,8 @@ enum DiskColumns
 };
 
 static void
-cb_sort_changed (GtkTreeSortable *model,
-                 gpointer         data)
+cb_sort_changed (GtkTreeSortable*,
+                 gpointer data)
 {
   GsmApplication *app = (GsmApplication *) data;
 
@@ -99,15 +100,23 @@ get_icon_for_path (const char*path)
   return name;
 }
 
-static GdkPixbuf*
+static GdkTexture *
 get_icon_for_device (const char *mountpoint)
 {
-  const char*icon_name = get_icon_for_path (mountpoint);
+  GdkTexture *icon;
+  GtkIconPaintable *icon_paintable;
+  GtkIconTheme *icon_theme;
+  const char *icon_name = get_icon_for_path (mountpoint);
 
+  // FIXME: defaults to a safe value
   if (!strcmp (icon_name, ""))
-    // FIXME: defaults to a safe value
     icon_name = "drive-harddisk";     // get_icon_for_path("/");
-  return gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon_name, 24, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
+
+  icon_theme = gtk_icon_theme_get_for_display (gdk_display_get_default ());
+  icon_paintable = gtk_icon_theme_lookup_icon (icon_theme, icon_name, NULL, 24, 1, GTK_TEXT_DIR_NONE, GTK_ICON_LOOKUP_PRELOAD);
+  icon = gdk_texture_new_for_pixbuf (gdk_pixbuf_new_from_file_at_size (g_file_get_path (gtk_icon_paintable_get_file (icon_paintable)), 24, 24, NULL));
+
+  return icon;
 }
 
 
@@ -142,8 +151,6 @@ find_disk_in_model (GtkTreeModel *model,
   return found;
 }
 
-
-
 static void
 remove_old_disks (GtkTreeModel             *model,
                   const glibtop_mountentry *entries,
@@ -193,7 +200,7 @@ add_disk (GtkListStore             *list,
           const glibtop_mountentry *entry,
           bool                      show_all_fs)
 {
-  GdkPixbuf*pixbuf;
+  GdkTexture *icon;
   GtkTreeIter iter;
   glibtop_fsusage usage;
   guint64 bused, bfree, bavail, btotal;
@@ -209,7 +216,7 @@ add_disk (GtkListStore             *list,
     }
 
   fsusage_stats (&usage, &bused, &bfree, &bavail, &btotal, &percentage);
-  pixbuf = get_icon_for_device (entry->mountdir);
+  icon = get_icon_for_device (entry->mountdir);
 
   /* if we can find a row with the same mountpoint, we get it but we
      still need to update all the fields.
@@ -219,7 +226,7 @@ add_disk (GtkListStore             *list,
     gtk_list_store_append (list, &iter);
 
   gtk_list_store_set (list, &iter,
-                      DISK_ICON, pixbuf,
+                      DISK_ICON, icon,
                       DISK_DEVICE, entry->devname,
                       DISK_DIR, entry->mountdir,
                       DISK_TYPE, entry->type,
@@ -232,8 +239,8 @@ add_disk (GtkListStore             *list,
 }
 
 static void
-mount_changed (GVolumeMonitor *monitor,
-               GMount         *mount,
+mount_changed (GVolumeMonitor*,
+               GMount*,
                GsmApplication *app)
 {
   disks_update (app);
@@ -310,17 +317,17 @@ disks_reset_timeout (GsmApplication *app)
 
 static void
 cb_disk_columns_changed (GtkTreeView *treeview,
-                         gpointer     data)
+                         gpointer)
 {
   gsm_tree_view_save_state (GSM_TREE_VIEW (treeview));
 }
 
 
 static void
-open_dir (GtkTreeView       *tree_view,
-          GtkTreePath       *path,
-          GtkTreeViewColumn *column,
-          gpointer           user_data)
+open_dir (GtkTreeView *tree_view,
+          GtkTreePath *path,
+          GtkTreeViewColumn*,
+          gpointer)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -359,9 +366,12 @@ cb_disk_list_destroying (GtkWidget *self,
 {
   g_signal_handlers_disconnect_by_func (self, (gpointer) cb_disk_columns_changed, data);
 
-  g_signal_handlers_disconnect_by_func (gtk_tree_view_get_model (GTK_TREE_VIEW (self)),
-                                        (gpointer) cb_sort_changed,
-                                        data);
+  GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (self));
+
+  if (model != NULL)
+    g_signal_handlers_disconnect_by_func (gtk_tree_view_get_model (GTK_TREE_VIEW (self)),
+                                          (gpointer) cb_sort_changed,
+                                          data);
 }
 
 
@@ -369,7 +379,7 @@ void
 create_disk_view (GsmApplication *app,
                   GtkBuilder     *builder)
 {
-  GtkScrolledWindow *scrolled;
+  GtkWidget *scrolled;
   GsmTreeView *disk_tree;
   GtkListStore *model;
   GtkTreeViewColumn *col;
@@ -388,8 +398,6 @@ create_disk_view (GsmApplication *app,
     N_("Used")
   };
 
-  scrolled = GTK_SCROLLED_WINDOW (gtk_builder_get_object (builder, "disks_scrolled"));
-
   model = gtk_list_store_new (DISK_N_COLUMNS,       /* n columns */
                               G_TYPE_STRING,        /* DISK_DEVICE */
                               G_TYPE_STRING,        /* DISK_DIR */
@@ -398,7 +406,7 @@ create_disk_view (GsmApplication *app,
                               G_TYPE_UINT64,        /* DISK_FREE */
                               G_TYPE_UINT64,        /* DISK_AVAIL */
                               G_TYPE_UINT64,        /* DISK_USED */
-                              GDK_TYPE_PIXBUF,      /* DISK_ICON */
+                              GDK_TYPE_TEXTURE,     /* DISK_ICON */
                               G_TYPE_INT            /* DISK_USED_PERCENTAGE */
                               );
   disk_tree = gsm_tree_view_new (g_settings_get_child (app->settings->gobj (), GSM_SETTINGS_CHILD_DISKS), TRUE);
@@ -406,7 +414,9 @@ create_disk_view (GsmApplication *app,
 
   g_signal_connect (G_OBJECT (disk_tree), "row-activated", G_CALLBACK (open_dir), NULL);
   app->disk_list = disk_tree;
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (disk_tree));
+
+  scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "disks_scrolled"));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (disk_tree));
   g_object_unref (G_OBJECT (model));
 
   /* icon + device */
@@ -416,7 +426,7 @@ create_disk_view (GsmApplication *app,
 
   gtk_tree_view_column_pack_start (col, cell, FALSE);
   gtk_tree_view_column_set_min_width (col, 30);
-  gtk_tree_view_column_set_attributes (col, cell, "pixbuf", DISK_ICON,
+  gtk_tree_view_column_set_attributes (col, cell, "texture", DISK_ICON,
                                        NULL);
 
   cell = gtk_cell_renderer_text_new ();
@@ -521,5 +531,5 @@ create_disk_view (GsmApplication *app,
     disks_reset_timeout (app);
   });
 
-  gtk_widget_show (GTK_WIDGET (disk_tree));
+  gtk_widget_set_visible (GTK_WIDGET (disk_tree), TRUE);
 }
