@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Procman - main window
  * Copyright (C) 2001 Kevin Vandersloot
  *
@@ -22,7 +21,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
+#include <adwaita.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -48,29 +47,15 @@
 static const char*LOAD_GRAPH_CSS = "\
 .loadgraph {\
     background: linear-gradient(to bottom,\
-                      @theme_bg_color,\
-                      @theme_base_color\
-                      );\
-    color: mix(@theme_fg_color, @theme_bg_color, 0.5);\
+                  @window_bg_color,\
+                  @view_bg_color);\
+    color: @window_fg_color;\
 }\
 ";
 
-static gboolean
-cb_window_key_press_event (GtkWidget *widget,
-                           GdkEvent  *event,
-                           gpointer   user_data)
-{
-  const char *current_page = gtk_stack_get_visible_child_name (GTK_STACK (GsmApplication::get ()->stack));
-
-  if (strcmp (current_page, "processes") == 0)
-    return gtk_search_bar_handle_event (GTK_SEARCH_BAR (user_data), event);
-
-  return FALSE;
-}
-
 static void
-search_text_changed (GtkEditable *entry,
-                     gpointer     data)
+search_text_changed (GtkEditable*,
+                     gpointer data)
 {
   GsmApplication * const app = static_cast<GsmApplication *>(data);
 
@@ -79,6 +64,7 @@ search_text_changed (GtkEditable *entry,
                                                                                   GTK_TREE_VIEW (app->tree))))));
 }
 
+/*
 static void
 set_affinity_visiblity (GtkWidget *widget,
                         gpointer   user_data)
@@ -90,40 +76,43 @@ set_affinity_visiblity (GtkWidget *widget,
   if (strcmp (name, "Set _Affinity") == 0)
     gtk_widget_set_visible (widget, false);
 #endif
-}
+}*/
 
 static void
 create_proc_view (GsmApplication *app,
                   GtkBuilder     *builder)
 {
   GsmTreeView *proctree;
-  GtkScrolledWindow *scrolled;
+  GtkWidget *scrolled;
 
   proctree = proctable_new (app);
-  scrolled = GTK_SCROLLED_WINDOW (gtk_builder_get_object (builder, "processes_scrolled"));
+  scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "processes_scrolled"));
 
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (proctree));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (proctree));
 
   app->proc_actionbar_revealer = GTK_REVEALER (gtk_builder_get_object (builder, "proc_actionbar_revealer"));
 
-  /* create popup_menu for the processes tab */
+  /* create popover_menu for the processes tab */
   GMenuModel *menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "process-popup-menu"));
 
-  app->popup_menu = GTK_MENU (gtk_menu_new_from_model (menu_model));
-  gtk_menu_attach_to_widget (app->popup_menu, GTK_WIDGET (app->main_window), NULL);
-
-  gtk_container_foreach (GTK_CONTAINER (app->popup_menu), set_affinity_visiblity, NULL);
+  app->proc_popover_menu = GTK_POPOVER (gtk_popover_menu_new_from_model (menu_model));
+  gtk_popover_set_has_arrow (app->proc_popover_menu, FALSE);
+  gtk_popover_set_default_widget (app->proc_popover_menu, GTK_WIDGET (scrolled));
+  gtk_widget_set_parent (GTK_WIDGET (app->proc_popover_menu), GTK_WIDGET (scrolled));
 
+  app->end_process_button = GTK_BUTTON (gtk_builder_get_object (builder, "end_process_button"));
+  app->search_button = GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "search_button"));
   app->search_bar = GTK_SEARCH_BAR (gtk_builder_get_object (builder, "proc_searchbar"));
   app->search_entry = GTK_SEARCH_ENTRY (gtk_builder_get_object (builder, "proc_searchentry"));
 
-  gtk_search_bar_connect_entry (app->search_bar, GTK_ENTRY (app->search_entry));
-  g_signal_connect (app->main_window, "key-press-event",
-                    G_CALLBACK (cb_window_key_press_event), app->search_bar);
+  gtk_search_bar_set_key_capture_widget (app->search_bar, GTK_WIDGET (app->main_window));
 
-  g_signal_connect (app->search_entry, "changed", G_CALLBACK (search_text_changed), app);
+  g_signal_connect (app->search_entry,
+                    "changed",
+                    G_CALLBACK (search_text_changed),
+                    app);
 
-  g_object_bind_property (app->search_bar, "search-mode-enabled", app->search_button, "active", (GBindingFlags)(G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE));
+  g_object_bind_property (app->search_bar, "search-mode-enabled", app->search_button, "active", (GBindingFlags)(G_BINDING_BIDIRECTIONAL));
 }
 
 static void
@@ -215,18 +204,36 @@ cb_net_out_color_changed (GsmColorButton *cp,
   change_settings_color (*app->settings.operator-> (), GSM_SETTING_NET_OUT_COLOR, cp);
 }
 
+static void
+cb_disk_read_color_changed (GsmColorButton *cp,
+                            gpointer        data)
+{
+  GsmApplication *app = (GsmApplication *) data;
+
+  change_settings_color (*app->settings.operator-> (), GSM_SETTING_DISK_READ_COLOR, cp);
+}
+
+static void
+cb_disk_write_color_changed (GsmColorButton *cp,
+                             gpointer        data)
+{
+  GsmApplication *app = (GsmApplication *) data;
+
+  change_settings_color (*app->settings.operator-> (), GSM_SETTING_DISK_WRITE_COLOR, cp);
+}
+
 static void
 create_sys_view (GsmApplication *app,
                  GtkBuilder     *builder)
 {
-  GtkBox *cpu_graph_box, *mem_graph_box, *net_graph_box;
-  GtkExpander *cpu_expander, *mem_expander, *net_expander;
+  GtkBox *cpu_graph_box, *mem_graph_box, *net_graph_box, *disk_graph_box;
+  GtkExpander *cpu_expander, *mem_expander, *net_expander, *disk_expander;
   GtkLabel *label, *cpu_label;
   GtkGrid *table;
   GsmColorButton *color_picker;
   GtkCssProvider *provider;
 
-  LoadGraph *cpu_graph, *mem_graph, *net_graph;
+  LoadGraph *cpu_graph, *mem_graph, *net_graph, *disk_graph;
 
   gint i;
   gchar *title_text;
@@ -234,8 +241,8 @@ create_sys_view (GsmApplication *app,
   gchar *title_template;
 
   provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (provider, LOAD_GRAPH_CSS, -1, NULL);
-  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  gtk_css_provider_load_from_string (provider, LOAD_GRAPH_CSS);
+  gtk_style_context_add_provider_for_display (gdk_display_get_default (), GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   // Translators: color picker title, %s is CPU, Memory, Swap, Receiving, Sending
   title_template = g_strdup (_("Pick a Color for “%s”"));
 
@@ -247,55 +254,49 @@ create_sys_view (GsmApplication *app,
 
   cpu_graph = new LoadGraph (LOAD_GRAPH_CPU);
   gtk_widget_set_size_request (GTK_WIDGET (load_graph_get_widget (cpu_graph)), -1, 70);
-  gtk_box_pack_start (cpu_graph_box,
-                      GTK_WIDGET (load_graph_get_widget (cpu_graph)),
-                      TRUE,
-                      TRUE,
-                      0);
+  gtk_box_prepend (cpu_graph_box,
+                   GTK_WIDGET (load_graph_get_widget (cpu_graph)));
 
   GtkGrid*cpu_table = GTK_GRID (gtk_builder_get_object (builder, "cpu_table"));
   gint cols = 4;
+  gint rows = (app->config.num_cpus + cols - 1) / cols;
 
   for (i = 0; i < app->config.num_cpus; i++)
     {
       GtkBox *temp_hbox;
 
       temp_hbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0));
-      gtk_widget_show (GTK_WIDGET (temp_hbox));
+      gtk_box_set_spacing (temp_hbox, 4);
       if (i < cols)
         gtk_grid_insert_column (cpu_table, i % cols);
       if ((i + 1) % cols == cols)
         gtk_grid_insert_row (cpu_table, (i + 1) / cols);
-      gtk_grid_attach (cpu_table, GTK_WIDGET (temp_hbox), i % cols, i / cols, 1, 1);
+      gtk_grid_attach (cpu_table, GTK_WIDGET (temp_hbox), i / rows, i % rows, 1, 1);
+
       color_picker = gsm_color_button_new (&cpu_graph->colors.at (i), GSMCP_TYPE_CPU);
       g_signal_connect (G_OBJECT (color_picker), "color-set",
                         G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
-      gtk_box_pack_start (temp_hbox, GTK_WIDGET (color_picker), FALSE, TRUE, 0);
+      gtk_box_append (temp_hbox, GTK_WIDGET (color_picker));
       gtk_widget_set_size_request (GTK_WIDGET (color_picker), 32, -1);
+
       if (app->config.num_cpus == 1)
         label_text = g_strdup (_("CPU"));
       else
         label_text = g_strdup_printf (_("CPU%d"), i + 1);
       title_text = g_strdup_printf (title_template, label_text);
       label = GTK_LABEL (gtk_label_new (label_text));
-      gtk_label_set_xalign (label, 0.0);
       if (app->config.num_cpus >= 10)
         gtk_label_set_width_chars (label, log10 (app->config.num_cpus) + 1 + 4);
       gsm_color_button_set_title (color_picker, title_text);
       g_free (title_text);
-      gtk_box_pack_start (temp_hbox, GTK_WIDGET (label), FALSE, FALSE, 6);
-      gtk_widget_show (GTK_WIDGET (label));
+      gtk_box_append (temp_hbox, GTK_WIDGET (label));
       g_free (label_text);
 
       cpu_label = make_tnum_label ();
 
       /* Reserve some space to avoid the layout changing with the values. */
       gtk_label_set_width_chars (cpu_label, 6);
-      gtk_label_set_xalign (cpu_label, 1.0);
-      gtk_widget_set_valign (GTK_WIDGET (cpu_label), GTK_ALIGN_CENTER);
-      gtk_widget_set_halign (GTK_WIDGET (cpu_label), GTK_ALIGN_START);
-      gtk_box_pack_start (temp_hbox, GTK_WIDGET (cpu_label), FALSE, FALSE, 0);
-      gtk_widget_show (GTK_WIDGET (cpu_label));
+      gtk_box_append (temp_hbox, GTK_WIDGET (cpu_label));
       load_graph_get_labels (cpu_graph)->cpu[i] = cpu_label;
     }
 
@@ -309,11 +310,8 @@ create_sys_view (GsmApplication *app,
 
   mem_graph = new LoadGraph (LOAD_GRAPH_MEM);
   gtk_widget_set_size_request (GTK_WIDGET (load_graph_get_widget (mem_graph)), -1, 70);
-  gtk_box_pack_start (mem_graph_box,
-                      GTK_WIDGET (load_graph_get_widget (mem_graph)),
-                      TRUE,
-                      TRUE,
-                      0);
+  gtk_box_prepend (mem_graph_box,
+                   GTK_WIDGET (load_graph_get_widget (mem_graph)));
 
   table = GTK_GRID (gtk_builder_get_object (builder, "mem_table"));
 
@@ -351,11 +349,8 @@ create_sys_view (GsmApplication *app,
 
   net_graph = new LoadGraph (LOAD_GRAPH_NET);
   gtk_widget_set_size_request (GTK_WIDGET (load_graph_get_widget (net_graph)), -1, 70);
-  gtk_box_pack_start (net_graph_box,
-                      GTK_WIDGET (load_graph_get_widget (net_graph)),
-                      TRUE,
-                      TRUE,
-                      0);
+  gtk_box_prepend (net_graph_box,
+                   GTK_WIDGET (load_graph_get_widget (net_graph)));
 
   table = GTK_GRID (gtk_builder_get_object (builder, "net_table"));
 
@@ -397,8 +392,60 @@ create_sys_view (GsmApplication *app,
   gtk_widget_set_hexpand (GTK_WIDGET (load_graph_get_labels (net_graph)->net_out), true);
   gtk_widget_set_halign (GTK_WIDGET (load_graph_get_labels (net_graph)->net_out), GTK_ALIGN_START);
 
-
   app->net_graph = net_graph;
+
+  /* The disk box */
+
+  disk_graph_box = GTK_BOX (gtk_builder_get_object (builder, "disk_graph_box"));
+  disk_expander = GTK_EXPANDER (gtk_builder_get_object (builder, "disk_expander"));
+  g_object_bind_property (disk_expander, "expanded", disk_expander, "vexpand", G_BINDING_DEFAULT);
+
+  disk_graph = new LoadGraph (LOAD_GRAPH_DISK);
+  gtk_widget_set_size_request (GTK_WIDGET (load_graph_get_widget (disk_graph)), -1, 70);
+  gtk_box_prepend (disk_graph_box,
+                   GTK_WIDGET (load_graph_get_widget (disk_graph)));
+
+  table = GTK_GRID (gtk_builder_get_object (builder, "disk_table"));
+
+  color_picker = gsm_color_button_new (
+    &disk_graph->colors.at (0), GSMCP_TYPE_DISK_READ);
+  gtk_widget_set_valign (GTK_WIDGET (color_picker), GTK_ALIGN_CENTER);
+  g_signal_connect (G_OBJECT (color_picker), "color-set",
+                    G_CALLBACK (cb_disk_read_color_changed), app);
+  title_text = g_strdup_printf (title_template, _("Reading"));
+  gsm_color_button_set_title (color_picker, title_text);
+  g_free (title_text);
+
+  label = GTK_LABEL (gtk_builder_get_object (builder, "reading_label"));
+  gtk_grid_attach_next_to (table, GTK_WIDGET (color_picker), GTK_WIDGET (label), GTK_POS_LEFT, 1, 2);
+  gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_read), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
+  label = GTK_LABEL (gtk_builder_get_object (builder, "total_read_label"));
+  gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_read_total), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
+
+  color_picker = gsm_color_button_new (
+    &disk_graph->colors.at (1), GSMCP_TYPE_DISK_WRITE);
+  gtk_widget_set_valign (GTK_WIDGET (color_picker), GTK_ALIGN_CENTER);
+  gtk_widget_set_hexpand (GTK_WIDGET (color_picker), true);
+  gtk_widget_set_halign (GTK_WIDGET (color_picker), GTK_ALIGN_END);
+
+  g_signal_connect (G_OBJECT (color_picker), "color-set",
+                    G_CALLBACK (cb_disk_write_color_changed), app);
+  title_text = g_strdup_printf (title_template, _("Writing"));
+  gsm_color_button_set_title (color_picker, title_text);
+  g_free (title_text);
+
+  label = GTK_LABEL (gtk_builder_get_object (builder, "writing_label"));
+  gtk_grid_attach_next_to (table, GTK_WIDGET (color_picker), GTK_WIDGET (label), GTK_POS_LEFT, 1, 2);
+  gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
+  label = GTK_LABEL (gtk_builder_get_object (builder, "total_written_label"));
+  gtk_grid_attach_next_to (table, GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write_total), GTK_WIDGET (label), GTK_POS_RIGHT, 1, 1);
+  gtk_widget_set_hexpand (GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write_total), true);
+  gtk_widget_set_halign (GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write_total), GTK_ALIGN_START);
+
+  gtk_widget_set_hexpand (GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write), true);
+  gtk_widget_set_halign (GTK_WIDGET (load_graph_get_labels (disk_graph)->disk_write), GTK_ALIGN_START);
+
+  app->disk_graph = disk_graph;
   g_free (title_template);
 }
 
@@ -420,6 +467,7 @@ on_activate_about (GSimpleAction *,
     "Robert Roth",
     "Stefano Facchini",
     "Jacob Barkdull",
+    "Ondřej Míchal",
     NULL
   };
 
@@ -434,22 +482,25 @@ on_activate_about (GSimpleAction *,
     NULL
   };
 
-  gtk_show_about_dialog (
+  adw_show_about_window (
     GTK_WINDOW (app->main_window),
-    "name", _("System Monitor"),
+    "application-name", _("System Monitor"),
     "comments", _("View current processes and monitor "
                   "system state"),
     "version", VERSION,
-    "website", "https://wiki.gnome.org/Apps/SystemMonitor",
+    "website", "https://apps.gnome.org/SystemMonitor/",
     "copyright", "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
     "Copyright \xc2\xa9 2005-2007 Benoît Dejean\n"
     "Copyright \xc2\xa9 2011 Chris Kühl",
-    "logo-icon-name", "org.gnome.SystemMonitor",
-    "authors", authors,
+    "application-icon", APP_ID,
+    "developer-name", _("The GNOME Project"),
+    "developers", authors,
     "artists", artists,
     "documenters", documenters,
     "translator-credits", _("translator-credits"),
     "license-type", GTK_LICENSE_GPL_2_0,
+    "support-url", "https://help.gnome.org/users/gnome-system-monitor/stable/",
+    "issue-url", "https://gitlab.gnome.org/GNOME/gnome-system-monitor/issues",
     NULL);
 }
 
@@ -460,7 +511,7 @@ on_activate_keyboard_shortcuts (GSimpleAction *,
 {
   GsmApplication *app = (GsmApplication *) data;
 
-  gtk_widget_show (GTK_WIDGET (gtk_application_window_get_help_overlay (GTK_APPLICATION_WINDOW (app->main_window))));
+  gtk_widget_set_visible (GTK_WIDGET (gtk_application_window_get_help_overlay (GTK_APPLICATION_WINDOW (app->main_window))), TRUE);
 }
 
 static void
@@ -486,27 +537,22 @@ kill_process_with_confirmation (GsmApplication *app,
 }
 
 static void
-on_activate_send_signal (GSimpleAction *,
-                         GVariant *parameter,
-                         gpointer  data)
+on_activate_send_signal (GSimpleAction *action,
+                         GVariant *,
+                         gpointer       data)
 {
   GsmApplication *app = (GsmApplication *) data;
 
-  /* no confirmation */
-  gint32 signal = g_variant_get_int32 (parameter);
+  const gchar *action_name = g_action_get_name (G_ACTION (action));
 
-  switch (signal)
-    {
-      case SIGCONT:
-        kill_process (app, signal);
-        break;
-
-      case SIGSTOP:
-      case SIGTERM:
-      case SIGKILL:
-        kill_process_with_confirmation (app, signal);
-        break;
-    }
+  if (g_strcmp0 (action_name, "send-signal-cont") == 0)
+    kill_process (app, SIGCONT);
+  else if (g_strcmp0 (action_name, "send-signal-stop") == 0)
+    kill_process_with_confirmation (app, SIGSTOP);
+  else if (g_strcmp0 (action_name, "send-signal-term") == 0)
+    kill_process_with_confirmation (app, SIGTERM);
+  else if (g_strcmp0 (action_name, "send-signal-kill") == 0)
+    kill_process_with_confirmation (app, SIGKILL);
 }
 
 static void
@@ -552,15 +598,15 @@ on_activate_process_properties (GSimpleAction *,
 static void
 on_activate_radio (GSimpleAction *action,
                    GVariant      *parameter,
-                   gpointer       data)
+                   gpointer)
 {
   g_action_change_state (G_ACTION (action), parameter);
 }
 
 static void
 on_activate_toggle (GSimpleAction *action,
-                    GVariant      *parameter,
-                    gpointer       data)
+                    GVariant*,
+                    gpointer)
 {
   GVariant *state = g_action_get_state (G_ACTION (action));
 
@@ -569,21 +615,13 @@ on_activate_toggle (GSimpleAction *action,
 }
 
 static void
-on_activate_search (GSimpleAction *action,
-                    GVariant      *parameter,
-                    gpointer       data)
+on_activate_search (GSimpleAction*,
+                    GVariant*,
+                    gpointer data)
 {
   GsmApplication *app = (GsmApplication *) data;
-  GVariant *state = g_action_get_state (G_ACTION (action));
-  gboolean is_search_shortcut = g_variant_get_boolean (parameter);
-  gboolean is_search_bar = gtk_search_bar_get_search_mode (app->search_bar);
 
-  gtk_widget_set_visible (GTK_WIDGET (app->search_bar), is_search_bar || is_search_shortcut);
-  if (is_search_shortcut && is_search_bar)
-    gtk_widget_grab_focus (GTK_WIDGET (app->search_entry));
-  else
-    g_action_change_state (G_ACTION (action), g_variant_new_boolean (!g_variant_get_boolean (state)));
-  g_variant_unref (state);
+  gtk_search_bar_set_search_mode (app->search_bar, !gtk_search_bar_get_search_mode (app->search_bar));
 }
 
 static void
@@ -597,6 +635,7 @@ change_show_page_state (GSimpleAction *action,
   auto tab = g_variant_get_string (state, NULL);
   app->settings->set_string (GSM_SETTING_CURRENT_TAB, tab);
   app->config.current_tab = tab;
+  adw_view_stack_set_visible_child_name (app->stack, tab);
 }
 
 static void
@@ -651,7 +690,7 @@ on_activate_priority (GSimpleAction *action,
 static void
 change_priority_state (GSimpleAction *action,
                        GVariant      *state,
-                       gpointer       data)
+                       gpointer)
 {
   g_simple_action_set_state (action, state);
 }
@@ -659,7 +698,8 @@ change_priority_state (GSimpleAction *action,
 static void
 update_page_activities (GsmApplication *app)
 {
-  const gchar *current_page = gtk_stack_get_visible_child_name (app->stack);
+  const gchar *current_page = adw_view_stack_get_visible_child_name (app->stack);
+
   if (app->config.current_tab != current_page)
     {
       app->settings->set_string (GSM_SETTING_CURRENT_TAB, current_page);
@@ -668,19 +708,18 @@ update_page_activities (GsmApplication *app)
 
   if (strcmp (current_page, "processes") == 0)
     {
-      GAction *search_action = g_action_map_lookup_action (G_ACTION_MAP (app->main_window),
-                                                           "search");
       proctable_update (app);
       proctable_thaw (app);
 
-      gtk_widget_show (GTK_WIDGET (app->end_process_button));
-      gtk_widget_show (GTK_WIDGET (app->search_button));
-      gtk_widget_show (GTK_WIDGET (app->process_menu_button));
-      gtk_widget_hide (GTK_WIDGET (app->window_menu_button));
+      gtk_widget_set_visible (GTK_WIDGET (app->end_process_button), TRUE);
+      gtk_widget_set_visible (GTK_WIDGET (app->search_button), TRUE);
+
+      gtk_menu_button_set_menu_model (app->app_menu_button, app->process_window_menu_model);
+      gtk_search_bar_set_key_capture_widget (app->search_bar, GTK_WIDGET (app->main_window));
 
       update_sensitivity (app);
 
-      if (g_variant_get_boolean (g_action_get_state (search_action)))
+      if (gtk_search_bar_get_search_mode (app->search_bar))
         gtk_widget_grab_focus (GTK_WIDGET (app->search_entry));
       else
         gtk_widget_grab_focus (GTK_WIDGET (app->tree));
@@ -689,10 +728,11 @@ update_page_activities (GsmApplication *app)
     {
       proctable_freeze (app);
 
-      gtk_widget_hide (GTK_WIDGET (app->end_process_button));
-      gtk_widget_hide (GTK_WIDGET (app->search_button));
-      gtk_widget_hide (GTK_WIDGET (app->process_menu_button));
-      gtk_widget_show (GTK_WIDGET (app->window_menu_button));
+      gtk_widget_set_visible (GTK_WIDGET (app->end_process_button), FALSE);
+      gtk_widget_set_visible (GTK_WIDGET (app->search_button), FALSE);
+
+      gtk_menu_button_set_menu_model (app->app_menu_button, app->generic_window_menu_model);
+      gtk_search_bar_set_key_capture_widget (app->search_bar, NULL);
 
       update_sensitivity (app);
     }
@@ -702,12 +742,14 @@ update_page_activities (GsmApplication *app)
       load_graph_start (app->cpu_graph);
       load_graph_start (app->mem_graph);
       load_graph_start (app->net_graph);
+      load_graph_start (app->disk_graph);
     }
   else
     {
       load_graph_stop (app->cpu_graph);
       load_graph_stop (app->mem_graph);
       load_graph_stop (app->net_graph);
+      load_graph_stop (app->disk_graph);
     }
 
   if (strcmp (current_page, "disks") == 0)
@@ -722,17 +764,16 @@ update_page_activities (GsmApplication *app)
 }
 
 static void
-cb_change_current_page (GtkStack   *stack,
-                        GParamSpec *pspec,
-                        gpointer    data)
+cb_change_current_page (AdwViewStack*,
+                        GParamSpec*,
+                        gpointer data)
 {
   update_page_activities ((GsmApplication *)data);
 }
 
 static gboolean
-cb_main_window_delete (GtkWidget *window,
-                       GdkEvent  *event,
-                       gpointer   data)
+cb_main_window_delete (GtkWindow*,
+                       gpointer data)
 {
   GsmApplication *app = (GsmApplication *) data;
 
@@ -741,17 +782,14 @@ cb_main_window_delete (GtkWidget *window,
   return TRUE;
 }
 
-static gboolean
-cb_main_window_state_changed (GtkWidget           *window,
-                              GdkEventWindowState *event,
-                              gpointer             data)
+static void
+cb_main_window_suspended (GtkWindow*,
+                          gboolean        suspended,
+                          GsmApplication *app)
 {
-  GsmApplication *app = (GsmApplication *) data;
   auto current_page = app->config.current_tab;
 
-  if (event->new_window_state & GDK_WINDOW_STATE_BELOW ||
-      event->new_window_state & GDK_WINDOW_STATE_ICONIFIED ||
-      event->new_window_state & GDK_WINDOW_STATE_WITHDRAWN)
+  if (suspended)
     {
       if (current_page == "processes")
         {
@@ -762,6 +800,7 @@ cb_main_window_state_changed (GtkWidget           *window,
           load_graph_stop (app->cpu_graph);
           load_graph_stop (app->mem_graph);
           load_graph_stop (app->net_graph);
+          load_graph_stop (app->disk_graph);
         }
       else if (current_page == "disks")
         {
@@ -780,6 +819,7 @@ cb_main_window_state_changed (GtkWidget           *window,
           load_graph_start (app->cpu_graph);
           load_graph_start (app->mem_graph);
           load_graph_start (app->net_graph);
+          load_graph_start (app->disk_graph);
         }
       else if (current_page == "disks")
         {
@@ -787,137 +827,118 @@ cb_main_window_state_changed (GtkWidget           *window,
           disks_thaw (app);
         }
     }
-  return FALSE;
 }
 
 void
 create_main_window (GsmApplication *app)
 {
-  HdyApplicationWindow *main_window;
-  GtkStack *stack;
-  GMenuModel *window_menu_model;
-  GMenuModel *process_menu_model;
   GdkDisplay *display;
   GdkMonitor *monitor;
   GdkRectangle monitor_geometry;
-
-  int width, height, xpos, ypos;
-
+  GdkSurface *surface;
   GtkBuilder *builder = gtk_builder_new ();
+  GtkNative *native;
+  GError *err = NULL;
+  int width, height;
 
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/interface.ui", NULL);
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/menus.ui", NULL);
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/gtk/help-overlay.ui", NULL);
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/interface.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/menus.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/gtk/help-overlay.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
 
-  main_window = HDY_APPLICATION_WINDOW (gtk_builder_get_object (builder, "main_window"));
-  gtk_window_set_application (GTK_WINDOW (main_window), app->gobj ());
-  gtk_widget_set_name (GTK_WIDGET (main_window), "gnome-system-monitor");
-  app->main_window = main_window;
+  app->main_window = ADW_APPLICATION_WINDOW (gtk_builder_get_object (builder, "main_window"));
+  gtk_window_set_application (GTK_WINDOW (app->main_window), app->gobj ());
+  gtk_widget_set_name (GTK_WIDGET (app->main_window), "gnome-system-monitor");
 
   gtk_application_window_set_help_overlay (GTK_APPLICATION_WINDOW (app->main_window),
                                            GTK_SHORTCUTS_WINDOW (gtk_builder_get_object (builder, "help_overlay")));
 
-  g_settings_get (app->settings->gobj (), GSM_SETTING_WINDOW_STATE, "(iiii)",
-                  &width, &height, &xpos, &ypos);
+  /* create the main stack */
+  app->stack = ADW_VIEW_STACK (gtk_builder_get_object (builder, "stack"));
+  create_proc_view (app, builder);
+  create_sys_view (app, builder);
+  create_disk_view (app, builder);
 
-  display = gdk_display_get_default ();
-  monitor = gdk_display_get_monitor_at_point (display, xpos, ypos);
-  if (monitor == NULL)
-    monitor = gdk_display_get_monitor (display, 0);
-  gdk_monitor_get_geometry (monitor, &monitor_geometry);
+  app->app_menu_button = GTK_MENU_BUTTON (gtk_builder_get_object (builder, "app_menu_button"));
+  app->generic_window_menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "generic-window-menu"));
+  app->process_window_menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "process-window-menu"));
 
-  width = CLAMP (width, 50, monitor_geometry.width);
-  height = CLAMP (height, 50, monitor_geometry.height);
-  xpos = CLAMP (xpos, monitor_geometry.x, monitor_geometry.x + monitor_geometry.width - width);
-  ypos = CLAMP (ypos, monitor_geometry.y, monitor_geometry.y + monitor_geometry.height - height);
+  // GtkMenuButton owns its models and thus an additional reference needs to be held
+  g_object_ref (G_OBJECT (app->generic_window_menu_model));
+  g_object_ref (G_OBJECT (app->process_window_menu_model));
 
-  gtk_window_set_default_size (GTK_WINDOW (main_window), width, height);
-  gtk_window_move (GTK_WINDOW (main_window), xpos, ypos);
-  if (app->settings->get_boolean (GSM_SETTING_MAXIMIZED))
-    gtk_window_maximize (GTK_WINDOW (main_window));
-
-  app->process_menu_button = GTK_MENU_BUTTON (gtk_builder_get_object (builder, "process_menu_button"));
-  process_menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "process-window-menu"));
-  gtk_menu_button_set_menu_model (app->process_menu_button, process_menu_model);
-
-  app->window_menu_button = GTK_MENU_BUTTON (gtk_builder_get_object (builder, "window_menu_button"));
-  window_menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "generic-window-menu"));
-  gtk_menu_button_set_menu_model (app->window_menu_button, window_menu_model);
-
-  app->end_process_button = GTK_BUTTON (gtk_builder_get_object (builder, "end_process_button"));
-
-  app->search_button = GTK_BUTTON (gtk_builder_get_object (builder, "search_button"));
+  gtk_menu_button_set_menu_model (app->app_menu_button, app->generic_window_menu_model);
 
   GActionEntry win_action_entries[] = {
-    { "about", on_activate_about, NULL, NULL, NULL },
-    { "show-help-overlay", on_activate_keyboard_shortcuts, NULL, NULL, NULL },
-    { "search", on_activate_search, "b", "false", NULL },
-    { "send-signal-stop", on_activate_send_signal, "i", NULL, NULL },
-    { "send-signal-cont", on_activate_send_signal, "i", NULL, NULL },
-    { "send-signal-term", on_activate_send_signal, "i", NULL, NULL },
-    { "send-signal-kill", on_activate_send_signal, "i", NULL, NULL },
-    { "priority", on_activate_priority, "i", "@i 0", change_priority_state },
-    { "set-affinity", on_activate_set_affinity, NULL, NULL, NULL },
-    { "memory-maps", on_activate_memory_maps, NULL, NULL, NULL },
-    { "open-files", on_activate_open_files, NULL, NULL, NULL },
-    { "process-properties", on_activate_process_properties, NULL, NULL, NULL },
-    { "refresh", on_activate_refresh, NULL, NULL, NULL },
-    { "show-page", on_activate_radio, "s", "'resources'", change_show_page_state },
-    { "show-whose-processes", on_activate_radio, "s", "'all'", change_show_processes_state },
-    { "show-dependencies", on_activate_toggle, NULL, "false", change_show_dependencies_state }
+    { "about", on_activate_about, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "show-help-overlay", on_activate_keyboard_shortcuts, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "search", on_activate_search, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "send-signal-stop", on_activate_send_signal, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "send-signal-cont", on_activate_send_signal, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "send-signal-term", on_activate_send_signal, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "send-signal-kill", on_activate_send_signal, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "priority", on_activate_priority, "i", "@i 0", change_priority_state, { 0, 0, 0 } },
+    { "set-affinity", on_activate_set_affinity, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "memory-maps", on_activate_memory_maps, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "open-files", on_activate_open_files, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "process-properties", on_activate_process_properties, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "refresh", on_activate_refresh, NULL, NULL, NULL, { 0, 0, 0 } },
+    { "show-page", on_activate_radio, "s", "'resources'", change_show_page_state, { 0, 0, 0 } },
+    { "show-whose-processes", on_activate_radio, "s", "'all'", change_show_processes_state, { 0, 0, 0 } },
+    { "show-dependencies", on_activate_toggle, NULL, "false", change_show_dependencies_state, { 0, 0, 0 } }
   };
-
-  g_action_map_add_action_entries (G_ACTION_MAP (main_window),
+  g_action_map_add_action_entries (G_ACTION_MAP (app->main_window),
                                    win_action_entries,
                                    G_N_ELEMENTS (win_action_entries),
                                    app);
 
-  GdkScreen*screen = gtk_widget_get_screen (GTK_WIDGET (main_window));
-  GdkVisual*visual = gdk_screen_get_rgba_visual (screen);
+  adw_view_stack_set_visible_child_name (ADW_VIEW_STACK (app->stack), app->config.current_tab.c_str ());
 
-  /* use visual, if available */
-  if (visual)
-    gtk_widget_set_visual (GTK_WIDGET (main_window), visual);
-
-  /* create the main stack */
-  app->stack = stack = GTK_STACK (gtk_builder_get_object (builder, "stack"));
-
-  create_proc_view (app, builder);
-
-  create_sys_view (app, builder);
-
-  create_disk_view (app, builder);
-
-  // Binding to GSM_SETTING_CURRENT_TAB precludes switching tabs when dconf fails
-  // to commit changes. Current tab is recorded in cb_change_current_page instead.
-  //g_settings_bind (app->settings->gobj (), GSM_SETTING_CURRENT_TAB, stack, "visible-child-name", G_SETTINGS_BIND_DEFAULT);
-
-  gtk_stack_set_visible_child_name(GTK_STACK (stack), app->config.current_tab.c_str ());
-
-  g_signal_connect (G_OBJECT (stack), "notify::visible-child",
-                    G_CALLBACK (cb_change_current_page), app);
-
-  g_signal_connect (G_OBJECT (main_window), "delete_event",
-                    G_CALLBACK (cb_main_window_delete),
+  g_signal_connect (G_OBJECT (app->stack),
+                    "notify::visible-child",
+                    G_CALLBACK (cb_change_current_page),
                     app);
-  g_signal_connect (G_OBJECT (main_window), "window-state-event",
-                    G_CALLBACK (cb_main_window_state_changed),
+  g_signal_connect (G_OBJECT (app->main_window),
+                    "notify::suspended",
+                    G_CALLBACK (cb_main_window_suspended),
+                    app);
+  g_signal_connect (G_OBJECT (app->main_window),
+                    "destroy",
+                    G_CALLBACK (cb_main_window_delete),
                     app);
 
   GAction *action;
 
-  action = g_action_map_lookup_action (G_ACTION_MAP (main_window),
+  action = g_action_map_lookup_action (G_ACTION_MAP (app->main_window),
                                        "show-dependencies");
   g_action_change_state (action,
                          g_settings_get_value (app->settings->gobj (), GSM_SETTING_SHOW_DEPENDENCIES));
 
 
-  action = g_action_map_lookup_action (G_ACTION_MAP (main_window),
+  action = g_action_map_lookup_action (G_ACTION_MAP (app->main_window),
                                        "show-whose-processes");
   g_action_change_state (action,
                          g_settings_get_value (app->settings->gobj (), GSM_SETTING_SHOW_WHOSE_PROCESSES));
 
-  gtk_widget_show (GTK_WIDGET (main_window));
+  // Surface is available only after a widget has been shown
+  gtk_widget_set_visible (GTK_WIDGET (app->main_window), true);
+
+  g_settings_bind (app->settings->gobj (), GSM_SETTING_WINDOW_WIDTH,
+                   app->main_window, "default-width",
+                   G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind (app->settings->gobj (), GSM_SETTING_WINDOW_HEIGHT,
+                   app->main_window, "default-height",
+                   G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind (app->settings->gobj (), GSM_SETTING_MAXIMIZED,
+                   app->main_window, "maximized",
+                   G_SETTINGS_BIND_DEFAULT);
 
   update_page_activities (app);
 
@@ -963,7 +984,7 @@ update_sensitivity (GsmApplication *app)
   gboolean processes_sensitivity, selected_sensitivity;
   GAction *action;
 
-  processes_sensitivity = (strcmp (gtk_stack_get_visible_child_name (GTK_STACK (app->stack)), "processes") == 0);
+  processes_sensitivity = (strcmp (adw_view_stack_get_visible_child_name (app->stack), "processes") == 0);
   selected_sensitivity = gtk_tree_selection_count_selected_rows (app->selection) > 0;
 
   for (i = 0; i != G_N_ELEMENTS (processes_actions); ++i)
