@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glib.h>
@@ -220,13 +219,6 @@ filter_date (time_t date)
       else
         e_utf8_strftime_fix_am_pm (buf, 26, _("%b %d %Y"), &then);
     }
-#if 0
-#ifdef CTIME_R_THREE_ARGS
-  ctime_r (&date, buf, 26);
-#else
-  ctime_r (&date, buf);
-#endif
-#endif
 
   return g_strdup (buf);
 }
