@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glib/gi18n.h>
@@ -30,20 +29,20 @@ Glib::RefPtr<Glib::Regex> re;
 bool
 matches (const string &filename) const
 {
-  return this->re->match (filename);
+  return this->re->match (filename.c_str ());
 }
 
 public:
-
 Lsof(const string &pattern,
      bool          caseless)
 {
-  Glib::RegexCompileFlags flags = static_cast<Glib::RegexCompileFlags>(0);
+  Glib::Regex::CompileFlags compile_flags = static_cast<Glib::Regex::CompileFlags>(0);
+  Glib::Regex::MatchFlags match_flags = static_cast<Glib::Regex::MatchFlags>(0);
 
   if (caseless)
-    flags |= Glib::REGEX_CASELESS;
+    compile_flags |= Glib::Regex::CompileFlags::CASELESS;
 
-  this->re = Glib::Regex::create (pattern, flags);
+  this->re = Glib::Regex::create (pattern.c_str (), compile_flags, match_flags);
 }
 
 
@@ -69,14 +68,9 @@ search (const ProcInfo &info,
 }
 };
 
-
-
-// GUI Stuff
-
-
 enum ProcmanLsof
 {
-  PROCMAN_LSOF_COL_PIXBUF,
+  PROCMAN_LSOF_COL_TEXTURE,
   PROCMAN_LSOF_COL_PROCESS,
   PROCMAN_LSOF_COL_PID,
   PROCMAN_LSOF_COL_FILENAME,
@@ -88,7 +82,7 @@ struct GUI: private procman::NonCopyable
 {
   GtkListStore *model;
   GtkSearchEntry *entry;
-  GtkWindow *window;
+  GtkWindow *dialog;
   GtkLabel *count;
   GsmApplication *app;
   bool case_insensitive;
@@ -98,16 +92,15 @@ struct GUI: private procman::NonCopyable
   GUI()
     : model (NULL),
     entry (NULL),
-    window (NULL),
+    dialog (NULL),
     count (NULL),
     app (NULL),
     case_insensitive (),
     regex_error_displayed (false)
   {
-    procman_debug ("New Lsof GUI %p", (void *) this);
+    procman_debug ("New Lsof GUI %p", (void *)this);
   }
 
-
   ~GUI()
   {
     procman_debug ("Destroying Lsof GUI %p", (void *) this);
@@ -123,15 +116,14 @@ struct GUI: private procman::NonCopyable
       title = g_strdup_printf (ngettext ("%d open file", "%d open files", count), count);
     else
       title = g_strdup_printf (ngettext ("%d matching open file", "%d matching open files", count), count);
-    gtk_window_set_title (this->window, title);
+    gtk_window_set_title (GTK_WINDOW (this->dialog), title);
     g_free (title);
   }
 
-
   string
   pattern () const
   {
-    return gtk_entry_get_text (GTK_ENTRY (this->entry));
+    return gtk_editable_get_text (GTK_EDITABLE (this->entry));
   }
 
 
@@ -143,7 +135,9 @@ struct GUI: private procman::NonCopyable
     bool regex_error = false;
 
     gtk_list_store_clear (this->model);
-    try {
+
+    try
+      {
         Lsof lsof (this->pattern (), this->case_insensitive);
 
         unsigned count = 0;
@@ -160,7 +154,7 @@ struct GUI: private procman::NonCopyable
                 GtkTreeIter file;
                 gtk_list_store_append (this->model, &file);
                 gtk_list_store_set (this->model, &file,
-                                    PROCMAN_LSOF_COL_PIXBUF, info.pixbuf->gobj (),
+                                    PROCMAN_LSOF_COL_TEXTURE, info.icon->gobj (),
                                     PROCMAN_LSOF_COL_PROCESS, info.name.c_str (),
                                     PROCMAN_LSOF_COL_PID, info.pid,
                                     PROCMAN_LSOF_COL_FILENAME, match.c_str (),
@@ -170,23 +164,17 @@ struct GUI: private procman::NonCopyable
 
         this->update_count (count);
       }
-    catch (Glib::RegexError&error) {
+    catch (Glib::RegexError &error)
+      {
         regex_error = true;
       }
 
     if (regex_error && !this->regex_error_displayed)
-      {
-        this->regex_error_displayed = true;
-        gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (entry)), GTK_STYLE_CLASS_ERROR);
-      }
+      this->regex_error_displayed = true;
     else if (!regex_error && this->regex_error_displayed)
-      {
-        this->regex_error_displayed = false;
-        gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET (entry)), GTK_STYLE_CLASS_ERROR);
-      }
+      this->regex_error_displayed = false;
   }
 
-
   static void
   search_changed (GtkSearchEntry *,
                   gpointer data)
@@ -194,48 +182,23 @@ struct GUI: private procman::NonCopyable
     static_cast<GUI*>(data)->search ();
   }
 
-
   static void
-  close_button_clicked (GtkButton *,
-                        gpointer data)
+  case_button_checked (GtkCheckButton *button,
+                       gpointer        data)
   {
-    GUI *gui = static_cast<GUI*>(data);
-
-    gtk_widget_destroy (GTK_WIDGET (gui->window));
-    delete gui;
-  }
-
-
-  static void
-  case_button_toggled (GtkToggleButton *button,
-                       gpointer         data)
-  {
-    bool state = gtk_toggle_button_get_active (button);
+    bool state = gtk_check_button_get_active (button);
 
     static_cast<GUI*>(data)->case_insensitive = state;
   }
-
-
-  static gboolean
-  window_delete_event (GtkWidget *,
-                       GdkEvent *,
-                       gpointer data)
-  {
-    delete static_cast<GUI*>(data);
-    return FALSE;
-  }
 };
 }
 
-
-
-
 void
 procman_lsof (GsmApplication *app)
 {
   GtkListStore *model = \
     gtk_list_store_new (PROCMAN_LSOF_NCOLS,
-                        GDK_TYPE_PIXBUF,    // PROCMAN_LSOF_COL_PIXBUF
+                        GDK_TYPE_TEXTURE,   // PROCMAN_LSOF_COL_TEXTURE
                         G_TYPE_STRING,      // PROCMAN_LSOF_COL_PROCESS
                         G_TYPE_UINT,        // PROCMAN_LSOF_COL_PID
                         G_TYPE_STRING       // PROCMAN_LSOF_COL_FILENAME
@@ -245,17 +208,16 @@ procman_lsof (GsmApplication *app)
 
   g_object_unref (model);
 
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *renderer;
+  gtk_tree_view_set_enable_search (tree, FALSE);
 
-  // PIXBUF / PROCESS
+  // TEXTURE / PROCESS
 
-  column = gtk_tree_view_column_new ();
+  GtkTreeViewColumn *column = gtk_tree_view_column_new ();
+  GtkCellRenderer *renderer = gtk_cell_renderer_pixbuf_new ();
 
-  renderer = gtk_cell_renderer_pixbuf_new ();
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer,
-                                       "pixbuf", PROCMAN_LSOF_COL_PIXBUF,
+                                       "texture", PROCMAN_LSOF_COL_TEXTURE,
                                        NULL);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -273,7 +235,6 @@ procman_lsof (GsmApplication *app)
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), PROCMAN_LSOF_COL_PROCESS,
                                         GTK_SORT_ASCENDING);
 
-
   // PID
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("PID"), renderer,
@@ -283,7 +244,6 @@ procman_lsof (GsmApplication *app)
   gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_GROW_ONLY);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
-
   // FILENAME
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("Filename"), renderer,
@@ -294,45 +254,40 @@ procman_lsof (GsmApplication *app)
   gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
-
-  GtkWindow *dialog;
-
   GtkBuilder *builder = gtk_builder_new ();
+  GError *err = NULL;
 
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/lsof.ui", NULL);
-
-  dialog = GTK_WINDOW (gtk_builder_get_object (builder, "lsof_dialog"));
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/lsof.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
 
+  GtkWindow *dialog = GTK_WINDOW (gtk_builder_get_object (builder, "lsof_dialog"));
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (app->main_window));
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
-  GtkSearchEntry *entry = GTK_SEARCH_ENTRY (gtk_builder_get_object (builder, "entry"));
-
+  GtkSearchBar *search_bar = GTK_SEARCH_BAR (gtk_builder_get_object (builder, "search_bar"));
+  GtkSearchEntry *search_entry = GTK_SEARCH_ENTRY (gtk_builder_get_object (builder, "search_entry"));
   GtkCheckButton *case_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "case_button"));
+  GtkWidget *scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled"));
 
-// Scrolled TreeView
-  GtkScrolledWindow *scrolled = GTK_SCROLLED_WINDOW (gtk_builder_get_object (builder, "scrolled"));
-
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (tree));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (tree));
+  gtk_search_bar_connect_entry (search_bar, GTK_EDITABLE (search_entry));
+  gtk_search_bar_set_key_capture_widget (search_bar, GTK_WIDGET (dialog));
 
   GUI *gui = new GUI;   // wil be deleted by the close button or delete-event
 
   gui->app = app;
   gui->model = model;
-  gui->window = dialog;
-  gui->entry = entry;
-  gui->case_insensitive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (case_button));
+  gui->dialog = dialog;
+  gui->entry = search_entry;
+  gui->case_insensitive = gtk_check_button_get_active (case_button);
 
-  g_signal_connect (G_OBJECT (entry), "search-changed",
+  g_signal_connect (G_OBJECT (search_entry), "search-changed",
                     G_CALLBACK (GUI::search_changed), gui);
   g_signal_connect (G_OBJECT (case_button), "toggled",
-                    G_CALLBACK (GUI::case_button_toggled), gui);
-  g_signal_connect (G_OBJECT (dialog), "delete-event",
-                    G_CALLBACK (GUI::window_delete_event), gui);
+                    G_CALLBACK (GUI::case_button_checked), gui);
 
-  gtk_builder_connect_signals (builder, NULL);
-
-  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_widget_show_all (GTK_WIDGET (dialog));
+  gtk_widget_set_visible (GTK_WIDGET (dialog), TRUE);
   gui->search ();
 
   g_object_unref (G_OBJECT (builder));
