@@ -18,6 +18,7 @@
 
 #include <config.h>
 
+#include <adwaita.h>
 #include <locale.h>
 #include <glib/gi18n.h>
 
@@ -33,6 +34,8 @@ main (int   argc,
   textdomain (GETTEXT_PACKAGE);
   setlocale (LC_ALL, "");
 
+  adw_init ();
+
   Glib::RefPtr<GsmApplication> application = GsmApplication::get ();
 
   return application->run (argc, argv);
