@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #include <config.h>
 
 #include <glibtop/procmap.h>
@@ -310,8 +309,7 @@ update_memmaps_dialog (MemMapsData *mmdata)
 
 
 static void
-dialog_response (GtkDialog *dialog,
-                 gint       response_id,
+dialog_response (AdwWindow *dialog,
                  gpointer   data)
 {
   MemMapsData * const mmdata = static_cast<MemMapsData*>(data);
@@ -319,7 +317,7 @@ dialog_response (GtkDialog *dialog,
   g_source_remove (mmdata->timer);
 
   delete mmdata;
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
@@ -451,16 +449,16 @@ memmaps_timer (gpointer data)
 
 static void
 create_single_memmaps_dialog (GtkTreeModel *model,
-                              GtkTreePath  *path,
+                              GtkTreePath*,
                               GtkTreeIter  *iter,
                               gpointer      data)
 {
   GsmApplication *app = static_cast<GsmApplication *>(data);
   MemMapsData *mmdata;
-  GtkDialog  *memmapsdialog;
+  AdwWindow  *memmapsdialog;
   GtkBox *dialog_box;
   GtkLabel *label;
-  GtkScrolledWindow *scrolled;
+  GtkWidget *scrolled;
   ProcInfo *info;
 
   gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
@@ -471,46 +469,38 @@ create_single_memmaps_dialog (GtkTreeModel *model,
   mmdata = create_memmapsdata (app);
   mmdata->info = info;
 
-  memmapsdialog = GTK_DIALOG (g_object_new (GTK_TYPE_DIALOG,
-                                            "title", _("Memory Maps"),
-                                            "use-header-bar", TRUE,
-                                            "destroy-with-parent", TRUE, NULL));
+  GtkBuilder *builder = gtk_builder_new ();
+  GError *err = NULL;
 
-  gtk_window_set_resizable (GTK_WINDOW (memmapsdialog), TRUE);
-  gtk_window_set_default_size (GTK_WINDOW (memmapsdialog), 620, 400);
-  gtk_container_set_border_width (GTK_CONTAINER (memmapsdialog), 5);
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/memmaps.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
 
-  dialog_box = GTK_BOX (gtk_dialog_get_content_area (memmapsdialog));
-  gtk_container_set_border_width (GTK_CONTAINER (dialog_box), 5);
+  memmapsdialog = ADW_WINDOW (gtk_builder_get_object (builder, "memmaps_dialog"));
+  dialog_box = GTK_BOX (gtk_builder_get_object (builder, "dialog_box"));
+  scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled"));
 
   label = procman_make_label_for_mmaps_or_ofiles (
     _("_Memory maps for process “%s” (PID %u):"),
     info->name.c_str (),
     info->pid);
 
-  gtk_box_pack_start (dialog_box, GTK_WIDGET (label), FALSE, TRUE, 0);
+  gtk_box_prepend (dialog_box, GTK_WIDGET (label));
 
-
-  scrolled = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                  GTK_POLICY_AUTOMATIC,
-                                  GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
-                                       GTK_SHADOW_IN);
-
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (mmdata->tree));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (mmdata->tree));
   gtk_label_set_mnemonic_widget (label, GTK_WIDGET (mmdata->tree));
 
-  gtk_box_pack_start (dialog_box, GTK_WIDGET (scrolled), TRUE, TRUE, 0);
+  gtk_window_set_transient_for (GTK_WINDOW (memmapsdialog), GTK_WINDOW (GsmApplication::get ()->main_window));
 
-  g_signal_connect (G_OBJECT (memmapsdialog), "response",
+  g_signal_connect (G_OBJECT (memmapsdialog), "close-request",
                     G_CALLBACK (dialog_response), mmdata);
 
-  gtk_window_set_transient_for (GTK_WINDOW (memmapsdialog), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_widget_show_all (GTK_WIDGET (memmapsdialog));
   mmdata->timer = g_timeout_add_seconds (5, memmaps_timer, mmdata);
-
   update_memmaps_dialog (mmdata);
+
+  gtk_window_present (GTK_WINDOW (memmapsdialog));
+
+  g_object_unref (G_OBJECT (builder));
 }
 
 
