@@ -95,7 +95,7 @@ failsafe:
 
 
 static void
-add_new_files (gpointer key,
+add_new_files (gpointer,
                gpointer value,
                gpointer data)
 {
@@ -141,7 +141,7 @@ static GList *old_maps = NULL;
 
 static gboolean
 classify_openfiles (GtkTreeModel *model,
-                    GtkTreePath  *path,
+                    GtkTreePath*,
                     GtkTreeIter  *iter,
                     gpointer      data)
 {
@@ -234,8 +234,7 @@ update_openfiles_dialog (GsmTreeView *tree)
 }
 
 static void
-close_openfiles_dialog (GtkDialog *dialog,
-                        gint       id,
+close_openfiles_dialog (AdwWindow *dialog,
                         gpointer   data)
 {
   GsmTreeView *tree = static_cast<GsmTreeView*>(data);
@@ -246,7 +245,7 @@ close_openfiles_dialog (GtkDialog *dialog,
   timer = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (tree), "timer"));
   g_source_remove (timer);
 
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  gtk_window_destroy (GTK_WINDOW (dialog));
 
   return;
 }
@@ -326,15 +325,15 @@ openfiles_timer (gpointer data)
 
 static void
 create_single_openfiles_dialog (GtkTreeModel *model,
-                                GtkTreePath  *path,
+                                GtkTreePath*,
                                 GtkTreeIter  *iter,
                                 gpointer      data)
 {
   GsmApplication *app = static_cast<GsmApplication *>(data);
-  GtkDialog *openfilesdialog;
-  GtkGrid *cmd_grid;
+  AdwWindow *openfilesdialog;
+  GtkBox *dialog_content;
   GtkLabel *label;
-  GtkScrolledWindow *scrolled;
+  GtkWidget *scrolled;
   GsmTreeView *tree;
   ProcInfo *info;
   guint timer;
@@ -345,34 +344,33 @@ create_single_openfiles_dialog (GtkTreeModel *model,
     return;
 
   GtkBuilder *builder = gtk_builder_new ();
+  GError *err = NULL;
 
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/openfiles.ui", NULL);
-
-  openfilesdialog = GTK_DIALOG (gtk_builder_get_object (builder, "openfiles_dialog"));
-
-  cmd_grid = GTK_GRID (gtk_builder_get_object (builder, "cmd_grid"));
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/openfiles.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
 
+  openfilesdialog = ADW_WINDOW (gtk_builder_get_object (builder, "openfiles_dialog"));
+  dialog_content = GTK_BOX (gtk_builder_get_object (builder, "dialog_content"));
 
   label = procman_make_label_for_mmaps_or_ofiles (
     _("_Files opened by process “%s” (PID %u):"),
     info->name.c_str (),
     info->pid);
 
-  gtk_grid_attach (cmd_grid, GTK_WIDGET (label), 0, 0, 1, 1);
+  gtk_box_prepend (dialog_content, GTK_WIDGET (label));
 
-  scrolled = GTK_SCROLLED_WINDOW (gtk_builder_get_object (builder, "scrolled"));
+  scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled"));
 
   tree = create_openfiles_tree (app);
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (tree));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (tree));
   g_object_set_data (G_OBJECT (tree), "selected_info", GUINT_TO_POINTER (info->pid));
 
-  g_signal_connect (G_OBJECT (openfilesdialog), "response",
+  g_signal_connect (G_OBJECT (openfilesdialog), "close-request",
                     G_CALLBACK (close_openfiles_dialog), tree);
 
-  gtk_builder_connect_signals (builder, NULL);
-
   gtk_window_set_transient_for (GTK_WINDOW (openfilesdialog), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_widget_show_all (GTK_WIDGET (openfilesdialog));
+  gtk_window_present (GTK_WINDOW (openfilesdialog));
 
   timer = g_timeout_add_seconds (5, openfiles_timer, tree);
   g_object_set_data (G_OBJECT (tree), "timer", GUINT_TO_POINTER (timer));
