@@ -32,7 +32,7 @@
 
 static void
 renice_single_process (GtkTreeModel *model,
-                       GtkTreePath  *path,
+                       GtkTreePath*,
                        GtkTreeIter  *iter,
                        gpointer      data)
 {
@@ -42,7 +42,7 @@ renice_single_process (GtkTreeModel *model,
   gint error;
   int saved_errno;
   gchar *error_msg;
-  GtkMessageDialog *dialog;
+  AdwMessageDialog *dialog;
 
   gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
 
@@ -80,19 +80,24 @@ renice_single_process (GtkTreeModel *model,
       "%s"),
     info->pid, args->arg_value, g_strerror (saved_errno));
 
-  dialog = GTK_MESSAGE_DIALOG (gtk_message_dialog_new (
+  dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (
+                                 GTK_WINDOW (GsmApplication::get ()->main_window),
                                  NULL,
-                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                 GTK_MESSAGE_ERROR,
-                                 GTK_BUTTONS_OK,
-                                 "%s", error_msg));
+                                 NULL));
+
+  adw_message_dialog_format_body (dialog, "%s", error_msg);
+
+  adw_message_dialog_add_response (dialog, "ok", _("_OK"));
+
+  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
   g_free (error_msg);
 
   g_signal_connect (dialog, "response",
-                    G_CALLBACK (gtk_widget_destroy), NULL);
+                    G_CALLBACK (gtk_window_destroy), NULL);
 
-  gtk_widget_show (GTK_WIDGET (dialog));
+  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 
@@ -121,7 +126,7 @@ renice (GsmApplication *app,
 
 static void
 kill_single_process (GtkTreeModel *model,
-                     GtkTreePath  *path,
+                     GtkTreePath*,
                      GtkTreeIter  *iter,
                      gpointer      data)
 {
@@ -130,7 +135,7 @@ kill_single_process (GtkTreeModel *model,
   ProcInfo *info;
   int error;
   int saved_errno;
-  GtkMessageDialog *dialog;
+  AdwMessageDialog *dialog;
 
   gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
 
@@ -167,19 +172,24 @@ kill_single_process (GtkTreeModel *model,
       "%s"),
     info->pid, args->arg_value, g_strerror (saved_errno));
 
-  dialog = GTK_MESSAGE_DIALOG (gtk_message_dialog_new (
+  dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (
+                                 GTK_WINDOW (GsmApplication::get ()->main_window),
                                  NULL,
-                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                 GTK_MESSAGE_ERROR,
-                                 GTK_BUTTONS_OK,
-                                 "%s", error_msg));
+                                 NULL));
+
+  adw_message_dialog_format_body (dialog, "%s", error_msg);
+
+  adw_message_dialog_add_response (dialog, "ok", _("_OK"));
+
+  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
   g_free (error_msg);
 
   g_signal_connect (dialog, "response",
-                    G_CALLBACK (gtk_widget_destroy), NULL);
+                    G_CALLBACK (gtk_window_destroy), NULL);
 
-  gtk_widget_show (GTK_WIDGET (dialog));
+  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 
