@@ -35,21 +35,22 @@
 #include "gsm_pkexec.h"
 #include "cgroups.h"
 
-static GtkDialog *renice_dialog = NULL;
+static AdwMessageDialog*renice_dialog = NULL;
 static gint new_nice_value = 0;
 
-
 static void
-kill_dialog_button_pressed (GtkDialog *dialog,
-                            gint       id,
-                            gpointer   data)
+kill_dialog_choose (GObject      *dialog,
+                    GAsyncResult *res,
+                    gpointer      data)
 {
   struct ProcActionArgs *kargs = static_cast<ProcActionArgs*>(data);
 
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  const gchar *res_id = adw_message_dialog_choose_finish (ADW_MESSAGE_DIALOG (dialog), res);
 
-  if (id == GTK_RESPONSE_OK)
-    kill_process (kargs->app, kargs->arg_value);
+  if (g_str_equal (res_id, adw_message_dialog_get_close_response (ADW_MESSAGE_DIALOG (dialog))))
+    return;
+
+  kill_process (kargs->app, kargs->arg_value);
 
   proctable_thaw (kargs->app);
   proctable_update (kargs->app);
@@ -60,11 +61,9 @@ void
 procdialog_create_kill_dialog (GsmApplication *app,
                                int             signal)
 {
-  GtkMessageDialog *kill_alert_dialog;
-  GtkWidget *confirm_button;
-
-  gchar *primary, *secondary, *button_text;
+  AdwMessageDialog *kill_alert_dialog;
   struct ProcActionArgs *kargs;
+  gchar *primary, *secondary, *button_text;
 
   proctable_freeze (app);
   kargs = g_new (ProcActionArgs, 1);
@@ -160,76 +159,58 @@ procdialog_create_kill_dialog (GsmApplication *app,
         break;
     }
 
-  kill_alert_dialog = GTK_MESSAGE_DIALOG (gtk_message_dialog_new (GTK_WINDOW (app->main_window),
-                                                                  static_cast<GtkDialogFlags>(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                                  GTK_MESSAGE_WARNING,
-                                                                  GTK_BUTTONS_NONE,
-                                                                  "%s",
-                                                                  primary));
+  kill_alert_dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (GTK_WINDOW (app->main_window), primary, secondary));
   g_free (primary);
 
-  gtk_message_dialog_format_secondary_text (kill_alert_dialog,
-                                            "%s",
-                                            secondary);
+  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (kill_alert_dialog),
+                                    "cancel", _("_Cancel"),
+                                    "apply", button_text,
+                                    NULL);
+  adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (kill_alert_dialog), "cancel");
+  adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (kill_alert_dialog), "cancel");
+  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (kill_alert_dialog), "apply", ADW_RESPONSE_DESTRUCTIVE);
 
-  gtk_dialog_add_button (GTK_DIALOG (kill_alert_dialog),
-                         _("_Cancel"), GTK_RESPONSE_CANCEL);
-
-  confirm_button = gtk_dialog_add_button (GTK_DIALOG (kill_alert_dialog),
-                                          button_text, GTK_RESPONSE_OK);
-  gtk_style_context_add_class (gtk_widget_get_style_context (confirm_button),
-                               GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
-
-  gtk_dialog_set_default_response (GTK_DIALOG (kill_alert_dialog),
-                                   GTK_RESPONSE_CANCEL);
-
-  g_signal_connect (G_OBJECT (kill_alert_dialog), "response",
-                    G_CALLBACK (kill_dialog_button_pressed), kargs);
-
-  gtk_widget_show_all (GTK_WIDGET (kill_alert_dialog));
+  adw_message_dialog_choose (ADW_MESSAGE_DIALOG (kill_alert_dialog),
+                             NULL,
+                             kill_dialog_choose,
+                             kargs);
 }
 
 static void
-renice_scale_changed (GtkAdjustment *adj,
-                      gpointer       data)
+renice_adjustment_value_changed (GtkAdjustment *adjustment,
+                                 gpointer       data)
 {
   GtkLabel *label = GTK_LABEL (data);
 
-  new_nice_value = int(gtk_adjustment_get_value (adj));
-  gchar*text = g_strdup (procman::get_nice_level_with_priority (new_nice_value));
+  new_nice_value = int(gtk_adjustment_get_value (adjustment));
 
+  gchar *text = g_strdup (procman::get_nice_level_with_priority (new_nice_value));
   gtk_label_set_text (label, text);
+
   g_free (text);
 }
 
 static void
-renice_dialog_button_pressed (GtkDialog *dialog,
-                              gint       id,
-                              gpointer   data)
+renice_dialog_response (AdwMessageDialog*,
+                        gchar   *response,
+                        gpointer data)
 {
   GsmApplication *app = static_cast<GsmApplication *>(data);
 
-  if (id == 100)
-    {
-      if (new_nice_value == -100)
-        return;
-      renice (app, new_nice_value);
-    }
+  if (g_str_equal (response, "change"))
+    renice (app, new_nice_value);
 
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  gtk_window_destroy (GTK_WINDOW (renice_dialog));
   renice_dialog = NULL;
 }
 
 void
 procdialog_create_renice_dialog (GsmApplication *app)
 {
-  ProcInfo *info;
-
-  GtkLabel *label;
-  GtkLabel *priority_label;
-  GtkAdjustment *renice_adj;
+  GtkAdjustment *renice_adjustment;
   GtkBuilder *builder;
-  gchar     *text;
+  GtkLabel *priority_label;
+  ProcInfo *info;
   gchar     *dialog_title;
 
   if (renice_dialog)
@@ -242,55 +223,47 @@ procdialog_create_renice_dialog (GsmApplication *app)
   if (!info)
     return;
 
+  new_nice_value = info->nice;
+
   builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/renice.ui", NULL);
+  GError *err = NULL;
+
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/renice.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
+
+  priority_label = GTK_LABEL (gtk_builder_get_object (builder, "priority_label"));
+  gtk_label_set_label (priority_label, procman::get_nice_level_with_priority (info->nice));
+
+  renice_adjustment = GTK_ADJUSTMENT (gtk_builder_get_object (builder, "renice_adjustment"));
+  gtk_adjustment_configure (GTK_ADJUSTMENT (renice_adjustment), info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
+  g_signal_connect (G_OBJECT (renice_adjustment),
+                    "value_changed",
+                    G_CALLBACK (renice_adjustment_value_changed),
+                    priority_label);
+
+  renice_dialog = ADW_MESSAGE_DIALOG (gtk_builder_get_object (builder, "renice_dialog"));
+  gtk_window_set_transient_for (GTK_WINDOW (renice_dialog), GTK_WINDOW (app->main_window));
 
-  renice_dialog = GTK_DIALOG (gtk_builder_get_object (builder, "renice_dialog"));
   if (selected_count == 1)
     dialog_title = g_strdup_printf (_("Change Priority of Process “%s” (PID: %u)"),
                                     info->name.c_str (), info->pid);
   else
     dialog_title = g_strdup_printf (ngettext ("Change Priority of the selected process", "Change Priority of %d selected processes", selected_count),
                                     selected_count);
-
-  gtk_window_set_title (GTK_WINDOW (renice_dialog), dialog_title);
-
+  adw_message_dialog_set_heading (ADW_MESSAGE_DIALOG (renice_dialog), dialog_title);
   g_free (dialog_title);
 
-  gtk_dialog_set_default_response (GTK_DIALOG (renice_dialog), 100);
-  new_nice_value = -100;
-
-  renice_adj = GTK_ADJUSTMENT (gtk_builder_get_object (builder, "renice_adj"));
-  gtk_adjustment_configure (GTK_ADJUSTMENT (renice_adj), info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
-
-  new_nice_value = 0;
-
-  priority_label = GTK_LABEL (gtk_builder_get_object (builder, "priority_label"));
-  gtk_label_set_label (priority_label, procman::get_nice_level_with_priority (info->nice));
-
-  text = g_strconcat ("<small><i><b>", _("Note:"), "</b> ",
-                      _("The priority of a process is given by its nice value. A lower nice value corresponds to a higher priority."),
-                      "</i></small>", NULL);
-  label = GTK_LABEL (gtk_builder_get_object (builder, "note_label"));
-  gtk_label_set_label (label, _(text));
-  gtk_label_set_line_wrap (label, TRUE);
-  g_free (text);
-
-  g_signal_connect (G_OBJECT (renice_dialog), "response",
-                    G_CALLBACK (renice_dialog_button_pressed), app);
-  g_signal_connect (G_OBJECT (renice_adj), "value_changed",
-                    G_CALLBACK (renice_scale_changed), priority_label);
-
-  gtk_window_set_transient_for (GTK_WINDOW (renice_dialog), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_widget_show_all (GTK_WIDGET (renice_dialog));
-
-  gtk_builder_connect_signals (builder, NULL);
+  g_signal_connect (G_OBJECT (renice_dialog),
+                    "response",
+                    G_CALLBACK (renice_dialog_response),
+                    app);
 
   g_object_unref (G_OBJECT (builder));
+
+  gtk_widget_set_visible (GTK_WIDGET (renice_dialog), TRUE);
 }
 
-
-
 static char *
 procman_action_to_command (ProcmanActionType type,
                            gint              pid,
@@ -332,7 +305,7 @@ multi_root_check (char *command)
  */
 gboolean
 procdialog_create_root_password_dialog (ProcmanActionType type,
-                                        GsmApplication   *app,
+                                        GsmApplication*,
                                         gint              pid,
                                         gint              extra_value)
 {
