@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Process properties dialog
  * Copyright (C) 2010 Krishnan Parthasarathi <krishnan.parthasarathi@gmail.com>
  *                    Robert Ancell <robert.ancell@canonical.com>
@@ -74,11 +73,6 @@ fill_proc_properties (GtkTreeView *tree,
     { N_("Resident Memory"), format_memsize (info->memres) },
     { N_("Writable Memory"), format_memsize (info->memwritable) },
     { N_("Shared Memory"), format_memsize (info->memshared) },
-#ifdef HAVE_WNCK
-    {
-      N_("X Server Memory"), format_memsize (info->memxserver)
-    },
-#endif
     {
       N_("CPU"), g_strdup_printf ("%.2f%%", info->pcpu)
     },
@@ -123,8 +117,7 @@ update_procproperties_dialog (GtkTreeView *tree)
 }
 
 static void
-close_procprop_dialog (GtkDialog *dialog,
-                       gint       id,
+close_procprop_dialog (AdwWindow *dialog,
                        gpointer   data)
 {
   GtkTreeView *tree = static_cast<GtkTreeView*>(data);
@@ -133,12 +126,12 @@ close_procprop_dialog (GtkDialog *dialog,
   timer = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (tree), "timer"));
   g_source_remove (timer);
 
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 static GtkTreeView *
-create_procproperties_tree (GsmApplication *app,
-                            ProcInfo       *info)
+create_procproperties_tree (GsmApplication*,
+                            ProcInfo *info)
 {
   GtkTreeView *tree;
   GtkListStore *model;
@@ -152,6 +145,7 @@ create_procproperties_tree (GsmApplication *app,
                               );
 
   tree = GTK_TREE_VIEW (gtk_tree_view_new_with_model (GTK_TREE_MODEL (model)));
+  gtk_widget_set_vexpand (GTK_WIDGET (tree), TRUE);
   g_object_unref (G_OBJECT (model));
 
   for (i = 0; i < NUM_COLS; i++)
@@ -188,17 +182,13 @@ procprop_timer (gpointer data)
 
 static void
 create_single_procproperties_dialog (GtkTreeModel *model,
-                                     GtkTreePath  *path,
+                                     GtkTreePath*,
                                      GtkTreeIter  *iter,
                                      gpointer      data)
 {
   GsmApplication *app = static_cast<GsmApplication *>(data);
 
-  GtkDialog *procpropdialog;
-  GtkBox *dialog_vbox, *vbox;
-  GtkBox *cmd_hbox;
   gchar *label;
-  GtkScrolledWindow *scrolled;
   GtkTreeView *tree;
   ProcInfo *info;
   guint timer;
@@ -208,54 +198,36 @@ create_single_procproperties_dialog (GtkTreeModel *model,
   if (!info)
     return;
 
-  procpropdialog = GTK_DIALOG (g_object_new (GTK_TYPE_DIALOG,
-                                             "use-header-bar", TRUE, NULL));
+  GtkBuilder *builder = gtk_builder_new ();
+  GError *err = NULL;
+
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/procproperties.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
+
+  GtkWindow *procpropdialog = GTK_WINDOW (gtk_builder_get_object (builder, "procprop_dialog"));
+  GtkWidget *scrolled = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled"));
 
   label = g_strdup_printf (_("%s (PID %u)"), info->name.c_str (), info->pid);
   gtk_window_set_title (GTK_WINDOW (procpropdialog), label);
   g_free (label);
 
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (procpropdialog), TRUE);
-
-  gtk_window_set_resizable (GTK_WINDOW (procpropdialog), TRUE);
-  gtk_window_set_default_size (GTK_WINDOW (procpropdialog), 575, 400);
-  gtk_container_set_border_width (GTK_CONTAINER (procpropdialog), 5);
-
-  vbox = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (procpropdialog)));
-  gtk_box_set_spacing (vbox, 2);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-
-  dialog_vbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 6));
-  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 5);
-  gtk_box_pack_start (vbox, GTK_WIDGET (dialog_vbox), TRUE, TRUE, 0);
-
-  cmd_hbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12));
-  gtk_box_pack_start (dialog_vbox, GTK_WIDGET (cmd_hbox), FALSE, FALSE, 0);
-
-  scrolled = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
-  gtk_scrolled_window_set_policy (scrolled,
-                                  GTK_POLICY_AUTOMATIC,
-                                  GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (scrolled,
-                                       GTK_SHADOW_IN);
-
   tree = create_procproperties_tree (app, info);
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (tree));
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled), GTK_WIDGET (tree));
   g_object_set_data (G_OBJECT (tree), "selected_info", GUINT_TO_POINTER (info->pid));
 
-  gtk_box_pack_start (dialog_vbox, GTK_WIDGET (scrolled), TRUE, TRUE, 0);
-  gtk_widget_show_all (GTK_WIDGET (scrolled));
-
-  g_signal_connect (G_OBJECT (procpropdialog), "response",
+  g_signal_connect (G_OBJECT (procpropdialog), "close-request",
                     G_CALLBACK (close_procprop_dialog), tree);
 
   gtk_window_set_transient_for (GTK_WINDOW (procpropdialog), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_widget_show_all (GTK_WIDGET (procpropdialog));
+  gtk_window_present (GTK_WINDOW (procpropdialog));
 
   timer = g_timeout_add_seconds (5, procprop_timer, tree);
   g_object_set_data (G_OBJECT (tree), "timer", GUINT_TO_POINTER (timer));
 
   update_procproperties_dialog (tree);
+
+  g_object_unref (G_OBJECT (builder));
 }
 
 void
