@@ -1,4 +1,3 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* Procman tree view and process updating
  * Copyright (C) 2001 Kevin Vandersloot
  *
@@ -20,7 +19,6 @@
 
 #include <config.h>
 
-
 #include <string.h>
 #include <math.h>
 #include <glib/gi18n.h>
@@ -44,11 +42,6 @@
 #include <set>
 #include <list>
 
-#ifdef HAVE_WNCK
-#define WNCK_I_KNOW_THIS_IS_UNSTABLE
-#include <libwnck/libwnck.h>
-#endif
-
 #include "application.h"
 #include "proctable.h"
 #include "prettytable.h"
@@ -60,10 +53,6 @@
 #include "legacy/treeview.h"
 #include "systemd.h"
 
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
-
 ProcInfo*
 ProcList::find (pid_t pid)
 {
@@ -95,47 +84,36 @@ cb_proctree_destroying (GtkTreeView *self,
 }
 
 static gboolean
-cb_tree_button_pressed (GtkWidget      *widget,
-                        GdkEventButton *event,
-                        gpointer        data)
+cb_tree_button_pressed (GtkGestureClick*,
+                        gint,
+                        gdouble         x,
+                        gdouble         y,
+                        GsmApplication *app)
 {
-  GsmApplication *app = (GsmApplication *) data;
-  GtkTreePath *path;
-  GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
+  GtkTreePath *path = NULL;
+  GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (app->tree));
+  int bwx, bwy;
 
-  if (!gdk_event_triggers_context_menu ((GdkEvent *) event))
-    return FALSE;
+  gtk_tree_view_convert_widget_to_bin_window_coords (GTK_TREE_VIEW (app->tree), x, y, &bwx, &bwy);
 
-  if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (app->tree), event->x, event->y, &path, NULL, NULL, NULL))
+  if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (app->tree), bwx, bwy, &path, NULL, NULL, NULL))
     return FALSE;
 
   if (!gtk_tree_selection_path_is_selected (selection, path))
-    {
-      if (!(event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)))
-        gtk_tree_selection_unselect_all (selection);
-      gtk_tree_selection_select_path (selection, path);
-    }
-
+    gtk_tree_selection_select_path (selection, path);
   gtk_tree_path_free (path);
 
-  gtk_menu_popup_at_pointer (GTK_MENU (app->popup_menu), NULL);
-  return TRUE;
-}
+  GdkRectangle rect = { x, y, 1, 1 };
 
-static gboolean
-cb_tree_popup_menu (GtkWidget *widget,
-                    gpointer   data)
-{
-  GsmApplication *app = (GsmApplication *) data;
-
-  gtk_menu_popup_at_pointer (GTK_MENU (app->popup_menu), NULL);
+  gtk_popover_set_pointing_to (GTK_POPOVER (app->proc_popover_menu), &rect);
+  gtk_popover_popup (GTK_POPOVER (app->proc_popover_menu));
 
   return TRUE;
 }
 
 void
 get_last_selected (GtkTreeModel *model,
-                   GtkTreePath  *path,
+                   GtkTreePath*,
                    GtkTreeIter  *iter,
                    gpointer      data)
 {
@@ -207,8 +185,8 @@ cb_timeout (gpointer data)
 }
 
 static void
-cb_refresh_icons (GtkIconTheme *theme,
-                  gpointer      data)
+cb_refresh_icons (GtkIconTheme*,
+                  gpointer data)
 {
   GsmApplication *app = (GsmApplication *) data;
 
@@ -245,9 +223,9 @@ iter_matches_search_key (GtkTreeModel *model,
   keys = g_strsplit_set (search_text, " |", -1);
   search_pattern = g_strjoinv ("|", keys);
   try {
-      regex = Glib::Regex::create (search_pattern, Glib::REGEX_CASELESS);
+      regex = Glib::Regex::create (search_pattern, Glib::Regex::CompileFlags::CASELESS);
     } catch (const Glib::Error&ex) {
-      regex = Glib::Regex::create (Glib::Regex::escape_string (search_pattern), Glib::REGEX_CASELESS);
+      regex = Glib::Regex::create (Glib::Regex::escape_string (search_pattern), Glib::Regex::CompileFlags::CASELESS);
     }
 
   found = (name && regex->match (name)) || (user && regex->match (user))
@@ -269,7 +247,7 @@ process_visibility_func (GtkTreeModel *model,
                          gpointer      data)
 {
   GsmApplication * const app = static_cast<GsmApplication *>(data);
-  const gchar *search_text = app->search_entry == NULL ? "" : gtk_entry_get_text (GTK_ENTRY (app->search_entry));
+  const gchar *search_text = app->search_entry == NULL ? "" : gtk_editable_get_text (GTK_EDITABLE (app->search_entry));
   GtkTreePath *tree_path = gtk_tree_model_get_path (model, iter);
 
   if (strcmp (search_text, "") == 0)
@@ -326,7 +304,7 @@ proctable_clear_tree (GsmApplication * const app)
 
 static void
 cb_show_dependencies_changed (Gio::Settings& settings,
-                              Glib::ustring  key,
+                              Glib::ustring,
                               GsmApplication*app)
 {
   if (app->timeout)
@@ -340,9 +318,9 @@ cb_show_dependencies_changed (Gio::Settings& settings,
 }
 
 static void
-cb_show_whose_processes_changed (Gio::Settings& settings,
-                                 Glib::ustring  key,
-                                 GsmApplication*app)
+cb_show_whose_processes_changed (Gio::Settings&,
+                                 Glib::ustring,
+                                 GsmApplication *app)
 {
   if (app->timeout)
     {
@@ -359,7 +337,7 @@ proctable_new (GsmApplication * const app)
   GtkTreeModelFilter *model_filter;
   GtkTreeModelSort *model_sort;
   GtkTreeSelection *selection;
-
+  GtkGesture *click_controller;
   GtkTreeViewColumn *column;
   GtkCellRenderer *cell_renderer;
   const gchar *titles[] = {
@@ -396,7 +374,6 @@ proctable_new (GsmApplication * const app)
     NULL,
     "POINTER"
   };
-
   gint i;
   auto settings = g_settings_get_child (app->settings->gobj (), GSM_SETTINGS_CHILD_PROCESSES);
 
@@ -428,20 +405,18 @@ proctable_new (GsmApplication * const app)
                               G_TYPE_UINT64,        /* Disk read    */
                               G_TYPE_UINT64,        /* Disk write   */
                               G_TYPE_STRING,        /* Priority     */
-                              GDK_TYPE_PIXBUF,      /* Icon         */
+                              GDK_TYPE_TEXTURE,     /* Icon         */
                               G_TYPE_POINTER,       /* ProcInfo     */
                               G_TYPE_STRING         /* Sexy tooltip */
                               );
 
   model_filter = GTK_TREE_MODEL_FILTER (gtk_tree_model_filter_new (GTK_TREE_MODEL (model), NULL));
-
   gtk_tree_model_filter_set_visible_func (model_filter, process_visibility_func, app, NULL);
 
   model_sort = GTK_TREE_MODEL_SORT (gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (model_filter)));
 
   proctree = gsm_tree_view_new (settings, TRUE);
   gtk_tree_view_set_model (GTK_TREE_VIEW (proctree), GTK_TREE_MODEL (model_sort));
-
   gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (proctree), COL_TOOLTIP);
   gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (proctree), app->settings->get_boolean (GSM_SETTING_SHOW_DEPENDENCIES));
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (proctree), FALSE);
@@ -452,7 +427,7 @@ proctable_new (GsmApplication * const app)
   cell_renderer = gtk_cell_renderer_pixbuf_new ();
   gtk_tree_view_column_pack_start (column, cell_renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, cell_renderer,
-                                       "pixbuf", COL_PIXBUF,
+                                       "texture", COL_ICON,
                                        NULL);
 
   cell_renderer = gtk_cell_renderer_text_new ();
@@ -479,11 +454,6 @@ proctable_new (GsmApplication * const app)
       GtkCellRenderer *cell;
       PangoAttrList *attrs = NULL;
 
-#ifndef HAVE_WNCK
-      if (i == COL_MEMXSERVER)
-        continue;
-#endif
-
       if (i == COL_MEMWRITABLE)
         continue;
 
@@ -499,14 +469,6 @@ proctable_new (GsmApplication * const app)
       // type
       switch (i)
         {
-#ifdef HAVE_WNCK
-          case COL_MEMXSERVER:
-            gtk_tree_view_column_set_cell_data_func (col, cell,
-                                                     &procman::size_cell_data_func,
-                                                     GUINT_TO_POINTER (i),
-                                                     NULL);
-            break;
-#endif
           case COL_VMSIZE:
           case COL_MEMRES:
           case COL_MEMSHARED:
@@ -577,9 +539,6 @@ proctable_new (GsmApplication * const app)
       // Tabular Numbers
       switch (i)
         {
-#ifdef HAVE_WNCK
-          case COL_MEMXSERVER:
-#endif
           case COL_PID:
           case COL_VMSIZE:
           case COL_MEMRES:
@@ -606,9 +565,6 @@ proctable_new (GsmApplication * const app)
       // sorting
       switch (i)
         {
-#ifdef HAVE_WNCK
-          case COL_MEMXSERVER:
-#endif
           case COL_VMSIZE:
           case COL_MEMRES:
           case COL_MEMSHARED:
@@ -642,9 +598,6 @@ proctable_new (GsmApplication * const app)
           case COL_VMSIZE:
           case COL_MEMRES:
           case COL_MEMSHARED:
-#ifdef HAVE_WNCK
-          case COL_MEMXSERVER:
-#endif
           case COL_CPU:
           case COL_NICE:
           case COL_PID:
@@ -697,25 +650,26 @@ proctable_new (GsmApplication * const app)
 
   gsm_tree_view_load_state (proctree);
 
-  GtkIconTheme*theme = gtk_icon_theme_get_default ();
+  GtkIconTheme*theme = gtk_icon_theme_get_for_display (gdk_display_get_default ());
   g_signal_connect (G_OBJECT (theme), "changed", G_CALLBACK (cb_refresh_icons), app);
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (proctree));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
   app->selection = selection;
 
-  gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+  click_controller = gtk_gesture_click_new ();
+  gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (click_controller), GDK_BUTTON_SECONDARY);
+  gtk_widget_add_controller (GTK_WIDGET (proctree), GTK_EVENT_CONTROLLER (click_controller));
+
+  g_signal_connect (G_OBJECT (click_controller), "pressed",
+                    G_CALLBACK (cb_tree_button_pressed), app);
 
   g_signal_connect (G_OBJECT (selection),
                     "changed",
                     G_CALLBACK (cb_row_selected), app);
-  g_signal_connect (G_OBJECT (proctree), "popup_menu",
-                    G_CALLBACK (cb_tree_popup_menu), app);
-  g_signal_connect (G_OBJECT (proctree), "button_press_event",
-                    G_CALLBACK (cb_tree_button_pressed), app);
 
   g_signal_connect (G_OBJECT (proctree), "destroy",
-                    G_CALLBACK (cb_proctree_destroying),
-                    app);
+                    G_CALLBACK (cb_proctree_destroying), app);
 
   g_signal_connect (G_OBJECT (proctree), "columns-changed",
                     G_CALLBACK (cb_save_tree_state), app);
@@ -731,8 +685,6 @@ proctable_new (GsmApplication * const app)
     cb_show_whose_processes_changed (*app->settings.operator-> (), key, app);
   });
 
-  gtk_widget_show (GTK_WIDGET (proctree));
-
   return proctree;
 }
 
@@ -834,22 +786,6 @@ get_process_memory_info (ProcInfo *info)
 {
   glibtop_proc_mem procmem;
 
-#ifdef HAVE_WNCK
-  info->memxserver = 0;
-#ifdef GDK_WINDOWING_X11
-  if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
-    {
-      WnckResourceUsage xresources;
-
-      wnck_pid_read_resource_usage (gdk_display_get_default (),
-                                    info->pid,
-                                    &xresources);
-
-      info->memxserver = xresources.total_bytes_estimate;
-    }
-#endif
-#endif
-
   glibtop_get_proc_mem (&procmem, info->pid);
 
   info->vmsize = procmem.vsize;
@@ -857,9 +793,6 @@ get_process_memory_info (ProcInfo *info)
   info->memshared = procmem.share;
 
   info->mem = info->memres - info->memshared;
-#ifdef HAVE_WNCK
-  info->mem += info->memxserver;
-#endif
 }
 
 static void
@@ -878,9 +811,6 @@ update_info_mutable_cols (ProcInfo *info)
   tree_store_update (model, &info->node, COL_VMSIZE, info->vmsize);
   tree_store_update (model, &info->node, COL_MEMRES, info->memres);
   tree_store_update (model, &info->node, COL_MEMSHARED, info->memshared);
-#ifdef HAVE_WNCK
-  tree_store_update (model, &info->node, COL_MEMXSERVER, info->memxserver);
-#endif
   tree_store_update (model, &info->node, COL_CPU, info->pcpu);
   tree_store_update (model, &info->node, COL_CPU_TIME, info->cpu_time);
   tree_store_update (model, &info->node, COL_DISK_READ_TOTAL, info->disk_read_bytes_total);
@@ -1083,7 +1013,7 @@ update_info (GsmApplication *app,
 
 ProcInfo::ProcInfo(pid_t pid)
   : node (),
-  pixbuf (),
+  icon (),
   pid (pid),
   ppid (-1),
   uid (-1)
@@ -1340,9 +1270,9 @@ proctable_free_table (GsmApplication * const app)
 }
 
 void
-ProcInfo::set_icon (Glib::RefPtr<Gdk::Pixbuf> icon)
+ProcInfo::set_icon (Glib::RefPtr<Gdk::Texture> icon)
 {
-  this->pixbuf = icon;
+  this->icon = icon;
 
   GtkTreeModel *model;
 
@@ -1350,7 +1280,7 @@ ProcInfo::set_icon (Glib::RefPtr<Gdk::Pixbuf> icon)
                                              gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (
                                                                               gtk_tree_view_get_model (GTK_TREE_VIEW (GsmApplication::get ()->tree))))));
   gtk_tree_store_set (GTK_TREE_STORE (model), &this->node,
-                      COL_PIXBUF, (this->pixbuf ? this->pixbuf->gobj () : NULL),
+                      COL_ICON, (this->icon ? this->icon->gobj () : NULL),
                       -1);
 }
 
