@@ -53,7 +53,7 @@ enum
   COL_DISK_READ_CURRENT,
   COL_DISK_WRITE_CURRENT,
   COL_PRIORITY,
-  COL_PIXBUF,
+  COL_ICON,
   COL_POINTER,
   COL_TOOLTIP,
   NUM_COLUMNS
