@@ -52,15 +52,15 @@ all_toggled (SetAffinityData *affinity)
   /* Check if any CPU's aren't set for this process */
   for (i = 1; i <= affinity->cpu_count; i++)
     /* If so, return FALSE */
-    if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (affinity->buttons[i])))
+    if (!gtk_check_button_get_active (GTK_CHECK_BUTTON (affinity->buttons[i])))
       return FALSE;
 
   return TRUE;
 }
 
 static void
-affinity_toggler_single (GtkToggleButton *button,
-                         gpointer         data)
+affinity_toggler_single (GtkCheckButton *button,
+                         gpointer        data)
 {
   SetAffinityData *affinity = static_cast<SetAffinityData *>(data);
   gboolean toggle_all_state = FALSE;
@@ -70,23 +70,23 @@ affinity_toggler_single (GtkToggleButton *button,
     return;
 
   /* Set toggle all state based on whether all are toggled */
-  if (gtk_toggle_button_get_active (button))
+  if (gtk_check_button_get_active (button))
     toggle_all_state = all_toggled (affinity);
 
   /* Block toggle all signal */
   affinity->toggle_all_blocked = TRUE;
 
   /* Set toggle all check box state */
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (affinity->buttons[0]),
-                                toggle_all_state);
+  gtk_check_button_set_active (GTK_CHECK_BUTTON (affinity->buttons[0]),
+                               toggle_all_state);
 
   /* Unblock toggle all signal */
   affinity->toggle_all_blocked = FALSE;
 }
 
 static void
-affinity_toggle_all (GtkToggleButton *toggle_all_button,
-                     gpointer         data)
+affinity_toggle_all (GtkCheckButton *check_all_button,
+                     gpointer        data)
 {
   SetAffinityData *affinity = static_cast<SetAffinityData *>(data);
 
@@ -98,15 +98,15 @@ affinity_toggle_all (GtkToggleButton *toggle_all_button,
     return;
 
   /* Set individual CPU toggles based on toggle all state */
-  state = gtk_toggle_button_get_active (toggle_all_button);
+  state = gtk_check_button_get_active (check_all_button);
 
   /* Block toggle single signal */
   affinity->toggle_single_blocked = TRUE;
 
   /* Set all CPU check boxes to specified state */
   for (i = 1; i <= affinity->cpu_count; i++)
-    gtk_toggle_button_set_active (
-      GTK_TOGGLE_BUTTON (affinity->buttons[i]),
+    gtk_check_button_set_active (
+      GTK_CHECK_BUTTON (affinity->buttons[i]),
       state);
 
   /* Unblock toggle single signal */
@@ -119,23 +119,27 @@ set_affinity_error (void)
   GtkWidget *dialog;
 
   /* Create error message dialog */
-  dialog = gtk_message_dialog_new (GTK_WINDOW (GsmApplication::get ()->main_window),
-                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                   GTK_MESSAGE_ERROR,
-                                   GTK_BUTTONS_CLOSE,
-                                   "GNU CPU Affinity error: %s",
-                                   g_strerror (errno));
+  dialog = adw_message_dialog_new (GTK_WINDOW (GsmApplication::get ()->main_window),
+                                   _("GNU CPU Affinity error"),
+                                   NULL);
+
+  adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog), "%s", g_strerror (errno));
+
+  adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (dialog), "close", _("_Close"));
+
+  /* Destroy dialog with parent */
+  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
   /* Set dialog as modal */
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
   /* Show the dialog */
-  gtk_widget_show (dialog);
+  gtk_window_present (GTK_WINDOW (dialog));
 
   /* Connect response signal to GTK widget destroy function */
   g_signal_connect_swapped (dialog,
                             "response",
-                            G_CALLBACK (gtk_widget_destroy),
+                            G_CALLBACK (gtk_window_destroy),
                             dialog);
 }
 
@@ -189,8 +193,8 @@ execute_taskset_command (gchar **cpu_list,
 }
 
 static void
-set_affinity (GtkToggleButton *button,
-              gpointer         data)
+set_affinity (GtkCheckButton*,
+              gpointer data)
 {
   SetAffinityData *affinity = static_cast<SetAffinityData *>(data);
 
@@ -199,6 +203,7 @@ set_affinity (GtkToggleButton *button,
 
   gchar   **cpu_list;
   GArray   *cpuset;
+  guint16  *cpus;
   guint32 i;
   gint taskset_cpu = 0;
 
@@ -206,15 +211,18 @@ set_affinity (GtkToggleButton *button,
   cpu_list = g_new0 (gchar *, affinity->cpu_count);
 
   /* Check whether we can get process's current affinity */
-  if (glibtop_get_proc_affinity (&get_affinity, affinity->pid) != NULL)
+  cpus = glibtop_get_proc_affinity (&get_affinity, affinity->pid);
+  if (cpus != NULL)
     {
+      g_free (cpus);
+
       /* If so, create array for CPU numbers */
       cpuset = g_array_new (FALSE, FALSE, sizeof (guint16));
 
       /* Run through all CPUs set for this process */
       for (i = 0; i < affinity->cpu_count; i++)
         /* Check if CPU check box button is active */
-        if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (affinity->buttons[i + 1])))
+        if (gtk_check_button_get_active (GTK_CHECK_BUTTON (affinity->buttons[i + 1])))
           {
             /* If so, get its CPU number as 16bit integer */
             guint16 n = i;
@@ -228,8 +236,10 @@ set_affinity (GtkToggleButton *button,
           }
 
       /* Set process affinity; Show message dialog upon error */
-      if (gsm_set_proc_affinity (&set_affinity, cpuset, affinity->pid) == NULL)
+      cpus = gsm_set_proc_affinity (&set_affinity, cpuset, affinity->pid);
+      if (cpus == NULL)
         {
+
           /* If so, check whether an access error occurred */
           if (errno == EPERM or errno == EACCES)
             /* If so, attempt to run taskset as root, show error on failure */
@@ -238,6 +248,7 @@ set_affinity (GtkToggleButton *button,
             /* If not, show error immediately */
             set_affinity_error ();
         }
+      g_free (cpus);
 
       /* Free memory for CPU strings */
       for (i = 0; i < affinity->cpu_count; i++)
@@ -253,12 +264,12 @@ set_affinity (GtkToggleButton *button,
     }
 
   /* Destroy dialog window */
-  gtk_widget_destroy (affinity->dialog);
+  gtk_window_destroy (GTK_WINDOW (affinity->dialog));
 }
 
 static void
 create_single_set_affinity_dialog (GtkTreeModel *model,
-                                   GtkTreePath  *path,
+                                   GtkTreePath*,
                                    GtkTreeIter  *iter,
                                    gpointer      data)
 {
@@ -270,8 +281,6 @@ create_single_set_affinity_dialog (GtkTreeModel *model,
   GtkWidget       *apply_button;
   GtkWidget       *dialog_vbox;
   GtkWidget       *label;
-  GtkWidget       *scrolled;
-  GtkStyleContext *scrolled_style;
   GtkGrid         *cpulist_grid;
 
   guint16               *affinity_cpus;
@@ -294,45 +303,24 @@ create_single_set_affinity_dialog (GtkTreeModel *model,
   /* Set initial check box array */
   affinity_data->buttons = g_new (GtkWidget *, app->config.num_cpus);
 
-  /* Create dialog window */
-  affinity_data->dialog = GTK_WIDGET (g_object_new (GTK_TYPE_DIALOG,
-                                                    "title", _("Set Affinity"),
-                                                    "use-header-bar", TRUE,
-                                                    "destroy-with-parent", TRUE,
-                                                    NULL));
+  GtkBuilder *builder = gtk_builder_new ();
+  GError *err = NULL;
 
-  /* Add cancel button to header bar */
-  cancel_button = gtk_dialog_add_button (GTK_DIALOG (affinity_data->dialog),
-                                         _("_Cancel"),
-                                         GTK_RESPONSE_CANCEL);
+  gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/setaffinity.ui", &err);
+  if (err != NULL)
+    g_error ("%s", err->message);
 
-  /* Add apply button to header bar */
-  apply_button = gtk_dialog_add_button (GTK_DIALOG (affinity_data->dialog),
-                                        _("_Apply"),
-                                        GTK_RESPONSE_APPLY);
+  affinity_data->dialog = GTK_WIDGET (gtk_builder_get_object (builder, "setaffinity_dialog"));
+  dialog_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_vbox"));
+  cpulist_grid = GTK_GRID (gtk_builder_get_object (builder, "cpulist_grid"));
+  affinity_data->buttons[0] = GTK_WIDGET (gtk_builder_get_object (builder, "allcpus_button"));
+  cancel_button = GTK_WIDGET (gtk_builder_get_object (builder, "cancel_button"));
+  apply_button = GTK_WIDGET (gtk_builder_get_object (builder, "apply_button"));
 
   /* Set dialog window "transient for" */
   gtk_window_set_transient_for (GTK_WINDOW (affinity_data->dialog),
                                 GTK_WINDOW (GsmApplication::get ()->main_window));
 
-  /* Set dialog window to be resizable */
-  gtk_window_set_resizable (GTK_WINDOW (affinity_data->dialog), TRUE);
-
-  /* Set default dialog window size */
-  gtk_widget_set_size_request (affinity_data->dialog, 600, 430);
-
-  /* Get dialog content area VBox */
-  dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (affinity_data->dialog));
-
-   /* Set dialog VBox margin */
-  gtk_widget_set_margin_top (GTK_WIDGET (dialog_vbox), 15);
-  gtk_widget_set_margin_bottom (GTK_WIDGET (dialog_vbox), 15);
-  gtk_widget_set_margin_start (GTK_WIDGET (dialog_vbox), 15);
-  gtk_widget_set_margin_end (GTK_WIDGET (dialog_vbox), 15);
-
-  /* Set dialog VBox spacing */
-  gtk_box_set_spacing (GTK_BOX (dialog_vbox), 10);
-
   /* Add selected process pid to affinity data */
   affinity_data->pid = info->pid;
 
@@ -350,52 +338,16 @@ create_single_set_affinity_dialog (GtkTreeModel *model,
                         info->pid));
 
   /* Add label to dialog VBox */
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, TRUE, 0);
-
-  /* Create scrolled box ("window") */
-  scrolled = gtk_scrolled_window_new (NULL, NULL);
-
-  /* Add view class to scrolled box style */
-  scrolled_style = gtk_widget_get_style_context (scrolled);
-  gtk_style_context_add_class (scrolled_style, "view");
-
-  /* Set scrolled box vertical and horizontal policies */
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                  GTK_POLICY_AUTOMATIC,
-                                  GTK_POLICY_AUTOMATIC);
-
-  /* Set scrolled box shadow */
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
-                                       GTK_SHADOW_IN);
-
-  /* Create grid for CPU list */
-  cpulist_grid = GTK_GRID (gtk_grid_new ());
-
-  /* Set CPU list grid margin */
-  gtk_widget_set_margin_top (GTK_WIDGET (cpulist_grid), 10);
-  gtk_widget_set_margin_bottom (GTK_WIDGET (cpulist_grid), 10);
-  gtk_widget_set_margin_start (GTK_WIDGET (cpulist_grid), 10);
-  gtk_widget_set_margin_end (GTK_WIDGET (cpulist_grid), 10);
-
-  /* Set grid row spacing */
-  gtk_grid_set_row_spacing (cpulist_grid, 10);
-
-  /* Create toggle all check box */
-  affinity_data->buttons[0] = gtk_check_button_new_with_label (_("Run on all CPUs"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (affinity_data->buttons[0]), TRUE);
-  gtk_widget_set_hexpand (affinity_data->buttons[0], TRUE);
+  gtk_box_prepend (GTK_BOX (dialog_vbox), label);
 
   /* Get process's current affinity */
   affinity_cpus = glibtop_get_proc_affinity (&affinity, info->pid);
 
   /* Set toggle all check box based on whether all CPUs are set for this process */
-  gtk_toggle_button_set_active (
-    GTK_TOGGLE_BUTTON (affinity_data->buttons[0]),
+  gtk_check_button_set_active (
+    GTK_CHECK_BUTTON (affinity_data->buttons[0]),
     affinity.all);
 
-  /* Add toggle all check box to CPU grid */
-  gtk_grid_attach (cpulist_grid, affinity_data->buttons[0], 0, 0, 1, 1);
-
   /* Run through all CPU buttons */
   for (button_n = 1; button_n < app->config.num_cpus + 1; button_n++)
     {
@@ -426,21 +378,15 @@ create_single_set_affinity_dialog (GtkTreeModel *model,
       affinity_cpu = affinity_cpus[affinity_i] + 1;
 
       /* Set CPU check box active */
-      gtk_toggle_button_set_active (
-        GTK_TOGGLE_BUTTON (affinity_data->buttons[affinity_cpu]),
+      gtk_check_button_set_active (
+        GTK_CHECK_BUTTON (affinity_data->buttons[affinity_cpu]),
         TRUE);
     }
 
-  /* Add CPU grid to scrolled box */
-  gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (cpulist_grid));
-
-  /* Add scrolled box to dialog VBox */
-  gtk_box_pack_start (GTK_BOX (dialog_vbox), scrolled, TRUE, TRUE, 0);
-
   /* Swap click signal on "Cancel" button */
   g_signal_connect_swapped (cancel_button,
                             "clicked",
-                            G_CALLBACK (gtk_widget_destroy),
+                            G_CALLBACK (gtk_window_destroy),
                             affinity_data->dialog);
 
   /* Connect click signal on "Apply" button */
@@ -456,7 +402,11 @@ create_single_set_affinity_dialog (GtkTreeModel *model,
                     affinity_data);
 
   /* Show dialog window */
-  gtk_widget_show_all (affinity_data->dialog);
+  gtk_window_present (GTK_WINDOW (affinity_data->dialog));
+
+  g_object_unref (G_OBJECT (builder));
+
+  g_free (affinity_cpus);
 }
 
 void
