@@ -33,6 +33,8 @@ procman_debug_real (const char *file,
 #define procman_debug(FMT, ...) procman_debug_real (__FILE__, __LINE__, __func__, FMT, ## __VA_ARGS__)
 
 Glib::ustring                      get_monospace_system_font_name (void);
+GtkLabel *                         init_tnum_label (gint     char_width,
+                                                    GtkAlign halign);
 GtkLabel *                         make_tnum_label (void);
 PangoAttrList *                    make_tnum_attr_list (void);
 std::tuple<double, double, double> hsv_to_rgb (double h,
@@ -187,24 +189,19 @@ gchar *     get_nice_level (gint nice);
 
 gchar *     get_nice_level_with_priority (gint nice);
 
+std::string format_volume (guint64 size,
+                           bool    want_bits = false);
 std::string format_rate (guint64 rate,
                          bool    want_bits = false);
 
-std::string format_network (guint64 rate);
+std::string format_network (guint64 size);
 std::string format_network_rate (guint64 rate);
 
-class NonCopyable
+struct NonCopyable
 {
-protected:
-NonCopyable()
-{
-}                         // = default
-~NonCopyable()
-{
-}                         // = default
-private:
-NonCopyable(const NonCopyable&) /* = delete */;
-NonCopyable& operator= (const NonCopyable&) /* = delete */;
+  NonCopyable() = default;
+  NonCopyable(const NonCopyable&) = delete;
+  NonCopyable& operator=(const NonCopyable&) = delete;
 };
 
 
